# extremecloudiq-api
ExtremeCloud IQ RESTful API for external and internal applications.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 25.2.0.123
- Package version: 25.2.0.123
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.extremenetworks.com/support](https://www.extremenetworks.com/support)

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import extremecloudiq
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import extremecloudiq
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import extremecloudiq
from pprint import pprint
from extremecloudiq.apis.tags import account_api
from extremecloudiq.model.paged_xiq_backup_history import PagedXiqBackupHistory
from extremecloudiq.model.xiq_account import XiqAccount
from extremecloudiq.model.xiq_default_device_password import XiqDefaultDevicePassword
from extremecloudiq.model.xiq_error import XiqError
from extremecloudiq.model.xiq_external_account import XiqExternalAccount
from extremecloudiq.model.xiq_login_response import XiqLoginResponse
from extremecloudiq.model.xiq_sort_order import XiqSortOrder
from extremecloudiq.model.xiq_third_party_application import XiqThirdPartyApplication
from extremecloudiq.model.xiq_update_vhm_setting_request import XiqUpdateVhmSettingRequest
from extremecloudiq.model.xiq_vhm_setting import XiqVhmSetting
from extremecloudiq.model.xiq_vhm_setting_info import XiqVhmSettingInfo
from extremecloudiq.model.xiq_vhm_status import XiqVhmStatus
from extremecloudiq.model.xiq_viq import XiqViq
from extremecloudiq.model.xiq_viq_export_import_status_response import XiqViqExportImportStatusResponse
from extremecloudiq.model.xiq_viq_export_response import XiqViqExportResponse
from extremecloudiq.model.xiq_viq_import_response import XiqViqImportResponse
from extremecloudiq.model.xiq_viq_operation_type import XiqViqOperationType
# Defining the host is optional and defaults to http://localhost:8081
# See configuration.py for a list of all supported configuration parameters.
configuration = extremecloudiq.Configuration(
    host = "http://localhost:8081"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): Bearer
configuration = extremecloudiq.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# Enter a context with an instance of the API client
with extremecloudiq.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = account_api.AccountApi(api_client)
    
    try:
        # Backup VIQ
        api_instance.backup_viq()
    except extremecloudiq.ApiException as e:
        print("Exception when calling AccountApi->backup_viq: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:8081*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**backup_viq**](docs/apis/tags/AccountApi.md#backup_viq) | **post** /account/viq/:backup | Backup VIQ
*AccountApi* | [**delete_backup**](docs/apis/tags/AccountApi.md#delete_backup) | **delete** /backup/history/delete | Backup History Delete
*AccountApi* | [**download_viq_report**](docs/apis/tags/AccountApi.md#download_viq_report) | **get** /account/viq/download | Download VIQ data file and logs
*AccountApi* | [**export_import_status**](docs/apis/tags/AccountApi.md#export_import_status) | **get** /account/viq/export-import-status | Get running export/import status 
*AccountApi* | [**export_viq**](docs/apis/tags/AccountApi.md#export_viq) | **post** /account/viq/export | [LRO] Export VIQ data
*AccountApi* | [**get_api_access_tokens**](docs/apis/tags/AccountApi.md#get_api_access_tokens) | **get** /account/third-party-applications | List Third Party Applications
*AccountApi* | [**get_default_device_password**](docs/apis/tags/AccountApi.md#get_default_device_password) | **get** /account/viq/default-device-password | Get the default device password in the account
*AccountApi* | [**get_home_account**](docs/apis/tags/AccountApi.md#get_home_account) | **get** /account/home | Get home ExtremeCloud IQ account info
*AccountApi* | [**get_vhm_setting**](docs/apis/tags/AccountApi.md#get_vhm_setting) | **get** /account/vhm/setting | Get Vhm Setting
*AccountApi* | [**get_vhm_status**](docs/apis/tags/AccountApi.md#get_vhm_status) | **get** /account/vhm/status | Get Vhm Status
*AccountApi* | [**get_viq_info**](docs/apis/tags/AccountApi.md#get_viq_info) | **get** /account/viq | Get VIQ Info
*AccountApi* | [**import_viq**](docs/apis/tags/AccountApi.md#import_viq) | **post** /account/viq/import | [LRO] Import VIQ data
*AccountApi* | [**list_backup_history**](docs/apis/tags/AccountApi.md#list_backup_history) | **get** /backup/history/grid | List backup history grid
*AccountApi* | [**list_external_accounts**](docs/apis/tags/AccountApi.md#list_external_accounts) | **get** /account/external | List accessible external guest accounts
*AccountApi* | [**reset_viq**](docs/apis/tags/AccountApi.md#reset_viq) | **post** /account/viq/:reset | Reset VIQ
*AccountApi* | [**restore_backup**](docs/apis/tags/AccountApi.md#restore_backup) | **post** /backup/history/:restore | Backup History Restore
*AccountApi* | [**switch_account**](docs/apis/tags/AccountApi.md#switch_account) | **post** /account/:switch | Switch to another ExtremeCloud IQ account
*AccountApi* | [**update_default_device_password**](docs/apis/tags/AccountApi.md#update_default_device_password) | **put** /account/viq/default-device-password | Update the default device password in the account
*AccountApi* | [**update_default_device_password_with_validation**](docs/apis/tags/AccountApi.md#update_default_device_password_with_validation) | **put** /v1/account/viq/default-device-password | Update the default device password in the account (with validation)
*AccountApi* | [**update_vhm_setting**](docs/apis/tags/AccountApi.md#update_vhm_setting) | **put** /account/vhm/setting/{id} | Update Vhm Setting
*AdministrationApi* | [**bulk_delete_api_access_token**](docs/apis/tags/AdministrationApi.md#bulk_delete_api_access_token) | **delete** /acct-api-token/:delete | Bulk Delete API Access token by ID
*AdministrationApi* | [**create_api_access_token**](docs/apis/tags/AdministrationApi.md#create_api_access_token) | **post** /acct-api-token | Create an API Access token
*AdministrationApi* | [**create_credential_distribution_group**](docs/apis/tags/AdministrationApi.md#create_credential_distribution_group) | **post** /credential-distribution-groups | Create a Credential Distribution Group
*AdministrationApi* | [**delete_api_access_token**](docs/apis/tags/AdministrationApi.md#delete_api_access_token) | **delete** /acct-api-token/{id} | Delete API Access token by ID
*AdministrationApi* | [**delete_credential_distribution_group**](docs/apis/tags/AdministrationApi.md#delete_credential_distribution_group) | **delete** /credential-distribution-groups | Delete Credential Distribution Group by ID
*AdministrationApi* | [**delete_third_party_api_connection**](docs/apis/tags/AdministrationApi.md#delete_third_party_api_connection) | **delete** /third-party-api-connection | Delete a third party api connection
*AdministrationApi* | [**export_to_csv5**](docs/apis/tags/AdministrationApi.md#export_to_csv5) | **get** /acct-api-token/export | Export all API access tokens to CSV
*AdministrationApi* | [**list_api_access_tokens**](docs/apis/tags/AdministrationApi.md#list_api_access_tokens) | **get** /acct-api-token | List API Access tokens
*AdministrationApi* | [**list_credential_distribution_groups**](docs/apis/tags/AdministrationApi.md#list_credential_distribution_groups) | **get** /credential-distribution-groups | List Credential Distribution Groups
*AdministrationApi* | [**list_third_party_api_connections**](docs/apis/tags/AdministrationApi.md#list_third_party_api_connections) | **get** /third-party-api-connection | List third party api connections
*AdministrationApi* | [**update_api_access_token**](docs/apis/tags/AdministrationApi.md#update_api_access_token) | **patch** /acct-api-token/{id} | Update API Access token by ID
*AdministrationApi* | [**update_credential_distribution_group**](docs/apis/tags/AdministrationApi.md#update_credential_distribution_group) | **put** /credential-distribution-groups/{id} | Update Credential Distribution Group by ID
*AdministrationApi* | [**update_third_party_api_connection**](docs/apis/tags/AdministrationApi.md#update_third_party_api_connection) | **put** /third-party-api-connection | Update a third party api connection
*AlertApi* | [**acknowledge_alerts**](docs/apis/tags/AlertApi.md#acknowledge_alerts) | **post** /alerts/:acknowledge | Acknowledge the alerts
*AlertApi* | [**count_alerts_by_group**](docs/apis/tags/AlertApi.md#count_alerts_by_group) | **get** /alerts/count-by-{group} | Count the alerts by different grouping
*AlertApi* | [**create_alert_email_subscription**](docs/apis/tags/AlertApi.md#create_alert_email_subscription) | **post** /alert-subscriptions/emails | Create alert email subscription
*AlertApi* | [**create_alert_policy**](docs/apis/tags/AlertApi.md#create_alert_policy) | **post** /alert-policies | Create a site based alert policy
*AlertApi* | [**create_alert_report**](docs/apis/tags/AlertApi.md#create_alert_report) | **post** /alerts/reports | [LRO] Create the alerts report
*AlertApi* | [**create_alert_webhook_subscription**](docs/apis/tags/AlertApi.md#create_alert_webhook_subscription) | **post** /alert-subscriptions/webhooks | Create alert webhook subscription
*AlertApi* | [**create_service_now_subscription**](docs/apis/tags/AlertApi.md#create_service_now_subscription) | **post** /alert-subscriptions/servicenow | Create ServiceNow subscription
*AlertApi* | [**delete_alert_email_subscription**](docs/apis/tags/AlertApi.md#delete_alert_email_subscription) | **delete** /alert-subscriptions/emails/{id} | Delete alert email subscription
*AlertApi* | [**delete_alert_policy**](docs/apis/tags/AlertApi.md#delete_alert_policy) | **delete** /alert-policies/{id} | Delete a site-based alert policy
*AlertApi* | [**delete_alert_webhook_subscription**](docs/apis/tags/AlertApi.md#delete_alert_webhook_subscription) | **delete** /alert-subscriptions/webhooks/{id} | Delete alert webhook subscription
*AlertApi* | [**delete_bulk_alert_subscription_email**](docs/apis/tags/AlertApi.md#delete_bulk_alert_subscription_email) | **post** /alert-subscriptions/emails/:delete | Delete alert email subscription in bulk
*AlertApi* | [**delete_bulk_alert_subscription_service_now**](docs/apis/tags/AlertApi.md#delete_bulk_alert_subscription_service_now) | **post** /alert-subscriptions/servicenow/:delete | Delete alert ServiceNow subscription in bulk
*AlertApi* | [**delete_bulk_alert_subscription_webhook**](docs/apis/tags/AlertApi.md#delete_bulk_alert_subscription_webhook) | **post** /alert-subscriptions/webhooks/:delete | Delete alert webhook subscription in bulk
*AlertApi* | [**disable_alert_rule**](docs/apis/tags/AlertApi.md#disable_alert_rule) | **post** /alert-policies/{policyId}/rules/{ruleId}/:disable | Disable a rule from an alert policy
*AlertApi* | [**download_alert_report**](docs/apis/tags/AlertApi.md#download_alert_report) | **get** /alerts/reports/{id} | Download the alerts report
*AlertApi* | [**enable_alert_rule**](docs/apis/tags/AlertApi.md#enable_alert_rule) | **post** /alert-policies/{policyId}/rules/{ruleId}/:enable | Enable a rule from an alert policy
*AlertApi* | [**get_alert_email_subscription**](docs/apis/tags/AlertApi.md#get_alert_email_subscription) | **get** /alert-subscriptions/emails/{id} | Get alert email subscription
*AlertApi* | [**get_alert_policy**](docs/apis/tags/AlertApi.md#get_alert_policy) | **get** /alert-policies/{id} | Get details of an alert policy
*AlertApi* | [**get_alert_rule**](docs/apis/tags/AlertApi.md#get_alert_rule) | **get** /alert-policies/{policyId}/rules/{ruleId} | Get details of an alert rule
*AlertApi* | [**get_alert_webhook_subscription**](docs/apis/tags/AlertApi.md#get_alert_webhook_subscription) | **get** /alert-subscriptions/webhooks/{id} | Get alert webhook subscription
*AlertApi* | [**get_service_now_subscription**](docs/apis/tags/AlertApi.md#get_service_now_subscription) | **get** /alert-subscriptions/servicenow/{id} | Get a specific ServiceNow subscription
*AlertApi* | [**list_alert_email_subscriptions**](docs/apis/tags/AlertApi.md#list_alert_email_subscriptions) | **get** /alert-subscriptions/emails | List alert email subscriptions
*AlertApi* | [**list_alert_policies**](docs/apis/tags/AlertApi.md#list_alert_policies) | **get** /alert-policies | List all alert policies
*AlertApi* | [**list_alert_webhook_subscriptions**](docs/apis/tags/AlertApi.md#list_alert_webhook_subscriptions) | **get** /alert-subscriptions/webhooks | List alert webhook subscriptions
*AlertApi* | [**list_alerts**](docs/apis/tags/AlertApi.md#list_alerts) | **get** /alerts | List the alerts
*AlertApi* | [**list_available_sites**](docs/apis/tags/AlertApi.md#list_available_sites) | **get** /alert-policies/available-sites | The list of current owner&#x27;s available sites
*AlertApi* | [**list_service_now_subscriptions**](docs/apis/tags/AlertApi.md#list_service_now_subscriptions) | **get** /alert-subscriptions/servicenow | List ServiceNow subscriptions
*AlertApi* | [**patch_service_now_subscription**](docs/apis/tags/AlertApi.md#patch_service_now_subscription) | **patch** /alert-subscriptions/servicenow/{id} | Partial or full update ServiceNow subscription
*AlertApi* | [**update_alert_email_subscription**](docs/apis/tags/AlertApi.md#update_alert_email_subscription) | **put** /alert-subscriptions/emails/{id} | Update alert email subscription
*AlertApi* | [**update_alert_policy**](docs/apis/tags/AlertApi.md#update_alert_policy) | **put** /alert-policies/{id} | Update a site-based alert policy
*AlertApi* | [**update_alert_rule**](docs/apis/tags/AlertApi.md#update_alert_rule) | **put** /alert-policies/{policyId}/rules/{ruleId} | Update an alert rule
*AlertApi* | [**update_alert_webhook_subscription**](docs/apis/tags/AlertApi.md#update_alert_webhook_subscription) | **put** /alert-subscriptions/webhooks/{id} | Update alert webhook subscription
*AlertApi* | [**update_service_now_subscription**](docs/apis/tags/AlertApi.md#update_service_now_subscription) | **put** /alert-subscriptions/servicenow/{id} | Update ServiceNow subscription
*AlertApi* | [**verify_subscription_email**](docs/apis/tags/AlertApi.md#verify_subscription_email) | **post** /alert-subscriptions/emails/{id}/:verify | Email Verification
*ApplicationApi* | [**list_application_top_clients_usage**](docs/apis/tags/ApplicationApi.md#list_application_top_clients_usage) | **get** /applications/{id}/clients/top{n} | List the TopN clients for a application
*ApplicationApi* | [**list_applications**](docs/apis/tags/ApplicationApi.md#list_applications) | **get** /applications | List the applications
*ApplicationApi* | [**list_top_applications_usage**](docs/apis/tags/ApplicationApi.md#list_top_applications_usage) | **get** /applications/top{n} | List the TopN applications
*AuthenticationApi* | [**login**](docs/apis/tags/AuthenticationApi.md#login) | **post** /login | User login with username and password
*AuthenticationApi* | [**logout**](docs/apis/tags/AuthenticationApi.md#logout) | **post** /logout | User logout (Revoke the current access token)
*AuthorizationApi* | [**check_permissions**](docs/apis/tags/AuthorizationApi.md#check_permissions) | **post** /auth/permissions/:check | Check permissions
*AuthorizationApi* | [**generate_api_token**](docs/apis/tags/AuthorizationApi.md#generate_api_token) | **post** /auth/apitoken | Generate new API token
*AuthorizationApi* | [**get_current_api_token_info**](docs/apis/tags/AuthorizationApi.md#get_current_api_token_info) | **get** /auth/apitoken/info | Get current API token details
*AuthorizationApi* | [**list_permissions**](docs/apis/tags/AuthorizationApi.md#list_permissions) | **get** /auth/permissions | Get permissions for current login user
*AuthorizationApi* | [**validate_api_token**](docs/apis/tags/AuthorizationApi.md#validate_api_token) | **post** /auth/apitoken/:validate | Validate API token
*ClientApi* | [**disconnect_client**](docs/apis/tags/ClientApi.md#disconnect_client) | **delete** /clients/byMac/{clientMac} | Disconnect the client
*ClientApi* | [**get_active_clients_count**](docs/apis/tags/ClientApi.md#get_active_clients_count) | **get** /clients/active/count | Get active clients count
*ClientApi* | [**get_client**](docs/apis/tags/ClientApi.md#get_client) | **get** /clients/{id} | Get client info
*ClientApi* | [**get_client_by_mac**](docs/apis/tags/ClientApi.md#get_client_by_mac) | **get** /clients/byMac/{clientMac} | Get client info by mac
*ClientApi* | [**get_client_summary**](docs/apis/tags/ClientApi.md#get_client_summary) | **get** /clients/summary | Get client summary metrics
*ClientApi* | [**get_client_usage**](docs/apis/tags/ClientApi.md#get_client_usage) | **get** /clients/usage | Get usage per client
*ClientApi* | [**list_active_clients**](docs/apis/tags/ClientApi.md#list_active_clients) | **get** /clients/active | List active clients
*ClientApi* | [**set_clients_aliases**](docs/apis/tags/ClientApi.md#set_clients_aliases) | **put** /clients/alias | Set the aliases for multiple clients
*ClientDetailsApi* | [**get_client_chart_data**](docs/apis/tags/ClientDetailsApi.md#get_client_chart_data) | **get** /client-details/overview/chart-data/{clientId} | Get Client chart data
*ClientDetailsApi* | [**get_client_details_info**](docs/apis/tags/ClientDetailsApi.md#get_client_details_info) | **get** /client-details/overview/info/{clientId} | Get Client Details Info
*ConfigurationAuthenticationApi* | [**create_external_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#create_external_radius_server) | **post** /radius-servers/external | Create external RADIUS server configuration
*ConfigurationAuthenticationApi* | [**create_internal_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#create_internal_radius_server) | **post** /radius-servers/internal | Create internal RADIUS server configuration
*ConfigurationAuthenticationApi* | [**create_ldap_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#create_ldap_server) | **post** /ldap-servers | Create LDAP server
*ConfigurationAuthenticationApi* | [**create_radius_client_object**](docs/apis/tags/ConfigurationAuthenticationApi.md#create_radius_client_object) | **post** /radius-client-objects | Create RADIUS client object configuration
*ConfigurationAuthenticationApi* | [**create_radius_proxy**](docs/apis/tags/ConfigurationAuthenticationApi.md#create_radius_proxy) | **post** /radius-proxies | Create RADIUS proxy configuration
*ConfigurationAuthenticationApi* | [**delete_bulk_internal_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#delete_bulk_internal_radius_server) | **delete** /radius-servers/internal | [LRO] Delete internal RADIUS server configuration
*ConfigurationAuthenticationApi* | [**delete_external_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#delete_external_radius_server) | **delete** /radius-servers/external/{id} | Delete external RADIUS server configuration
*ConfigurationAuthenticationApi* | [**delete_internal_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#delete_internal_radius_server) | **delete** /radius-servers/internal/{id} | Delete internal RADIUS server configuration
*ConfigurationAuthenticationApi* | [**delete_ldap_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#delete_ldap_server) | **delete** /ldap-servers/{id} | Delete a LDAP server
*ConfigurationAuthenticationApi* | [**delete_radius_client_object**](docs/apis/tags/ConfigurationAuthenticationApi.md#delete_radius_client_object) | **delete** /radius-client-objects/{id} | Delete a RADIUS client object configuration
*ConfigurationAuthenticationApi* | [**delete_radius_proxy**](docs/apis/tags/ConfigurationAuthenticationApi.md#delete_radius_proxy) | **delete** /radius-proxies/{id} | Delete the RADIUS proxy configuration
*ConfigurationAuthenticationApi* | [**get_external_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#get_external_radius_server) | **get** /radius-servers/external/{id} | Get external RADIUS server by ID
*ConfigurationAuthenticationApi* | [**get_internal_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#get_internal_radius_server) | **get** /radius-servers/internal/{id} | Get internal RADIUS server by ID
*ConfigurationAuthenticationApi* | [**get_ldap_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#get_ldap_server) | **get** /ldap-servers/{id} | Get LDAP server by ID
*ConfigurationAuthenticationApi* | [**get_radius_client_object**](docs/apis/tags/ConfigurationAuthenticationApi.md#get_radius_client_object) | **get** /radius-client-objects/{id} | Get RADIUS client object by ID
*ConfigurationAuthenticationApi* | [**get_radius_proxy**](docs/apis/tags/ConfigurationAuthenticationApi.md#get_radius_proxy) | **get** /radius-proxies/{id} | Get the RADIUS proxy configuration
*ConfigurationAuthenticationApi* | [**list_active_directory_servers**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_active_directory_servers) | **get** /ad-servers | List active directory servers
*ConfigurationAuthenticationApi* | [**list_captive_web_portals**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_captive_web_portals) | **get** /cwps | List captive web portals
*ConfigurationAuthenticationApi* | [**list_external_radius_servers**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_external_radius_servers) | **get** /radius-servers/external | List external RADIUS servers
*ConfigurationAuthenticationApi* | [**list_internal_radius_devices**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_internal_radius_devices) | **get** /radius-servers/internal/devices | List all internal RADIUS devices
*ConfigurationAuthenticationApi* | [**list_internal_radius_servers**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_internal_radius_servers) | **get** /radius-servers/internal | List all internal RADIUS servers
*ConfigurationAuthenticationApi* | [**list_ldap_servers**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_ldap_servers) | **get** /ldap-servers | List LDAP servers
*ConfigurationAuthenticationApi* | [**list_radius_client_objects**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_radius_client_objects) | **get** /radius-client-objects | List RADIUS client objects
*ConfigurationAuthenticationApi* | [**list_radius_proxies**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_radius_proxies) | **get** /radius-proxies | List RADIUS proxies
*ConfigurationAuthenticationApi* | [**list_radius_proxy_devices**](docs/apis/tags/ConfigurationAuthenticationApi.md#list_radius_proxy_devices) | **get** /radius-proxies/devices | List Radius proxy devices
*ConfigurationAuthenticationApi* | [**update_external_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#update_external_radius_server) | **put** /radius-servers/external/{id} | Update external RADIUS server configuration
*ConfigurationAuthenticationApi* | [**update_internal_radius_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#update_internal_radius_server) | **put** /radius-servers/internal/{id} | Update internal RADIUS server configuration
*ConfigurationAuthenticationApi* | [**update_ldap_server**](docs/apis/tags/ConfigurationAuthenticationApi.md#update_ldap_server) | **put** /ldap-servers/{id} | Update LDAP server configuration
*ConfigurationAuthenticationApi* | [**update_radius_client_object**](docs/apis/tags/ConfigurationAuthenticationApi.md#update_radius_client_object) | **put** /radius-client-objects/{id} | Update RADIUS client object configuration
*ConfigurationAuthenticationApi* | [**update_radius_proxy**](docs/apis/tags/ConfigurationAuthenticationApi.md#update_radius_proxy) | **put** /radius-proxies/{id} | Update RADIUS proxy configuration
*ConfigurationBasicApi* | [**create_vlan_profile**](docs/apis/tags/ConfigurationBasicApi.md#create_vlan_profile) | **post** /vlan-profiles | Create VLAN profile
*ConfigurationBasicApi* | [**delete_vlan_profile**](docs/apis/tags/ConfigurationBasicApi.md#delete_vlan_profile) | **delete** /vlan-profiles/{id} | Delete a VLAN profile
*ConfigurationBasicApi* | [**delete_vlan_profiles**](docs/apis/tags/ConfigurationBasicApi.md#delete_vlan_profiles) | **post** /vlan-profiles/:delete | [LRO] Delete VLAN profiles
*ConfigurationBasicApi* | [**get_vlan_profile**](docs/apis/tags/ConfigurationBasicApi.md#get_vlan_profile) | **get** /vlan-profiles/{id} | Get a VLAN profile
*ConfigurationBasicApi* | [**list_vlan_profiles**](docs/apis/tags/ConfigurationBasicApi.md#list_vlan_profiles) | **get** /vlan-profiles | List VLAN profiles
*ConfigurationBasicApi* | [**update_vlan_profile**](docs/apis/tags/ConfigurationBasicApi.md#update_vlan_profile) | **patch** /vlan-profiles/{id} | Update a VLAN profile
*ConfigurationCertificateApi* | [**list_certificates**](docs/apis/tags/ConfigurationCertificateApi.md#list_certificates) | **get** /certificates | List certificates
*ConfigurationDeploymentApi* | [**delete_firmware_upgrade_schedule**](docs/apis/tags/ConfigurationDeploymentApi.md#delete_firmware_upgrade_schedule) | **delete** /deployments/{deploymentId} | Delete the deployment schedule by ID
*ConfigurationDeploymentApi* | [**deploy_config**](docs/apis/tags/ConfigurationDeploymentApi.md#deploy_config) | **post** /deployments | [LRO] Push configuration and upgrade firmware
*ConfigurationDeploymentApi* | [**get_deploy_overview**](docs/apis/tags/ConfigurationDeploymentApi.md#get_deploy_overview) | **get** /deployments/overview | Get configuration deployment overview
*ConfigurationDeploymentApi* | [**get_deploy_status**](docs/apis/tags/ConfigurationDeploymentApi.md#get_deploy_status) | **get** /deployments/status | Get configuration deployment status
*ConfigurationDeploymentApi* | [**get_deployment_by_id_status**](docs/apis/tags/ConfigurationDeploymentApi.md#get_deployment_by_id_status) | **get** /deployments/{deploymentId}/status | [LRO] Get firmware deployment status by ID
*ConfigurationDeploymentApi* | [**get_deployment_details_by_id**](docs/apis/tags/ConfigurationDeploymentApi.md#get_deployment_details_by_id) | **get** /deployments/{deploymentId} | Get deployment details by Id
*ConfigurationDeploymentApi* | [**get_device_firmware_metadatas**](docs/apis/tags/ConfigurationDeploymentApi.md#get_device_firmware_metadatas) | **post** /deployments/firmware-metadatas | Get device firmware metadatas
*ConfigurationDeploymentApi* | [**get_list_of_deployments**](docs/apis/tags/ConfigurationDeploymentApi.md#get_list_of_deployments) | **get** /deployments | Get list of deployments
*ConfigurationDeploymentApi* | [**update_firmware_upgrade_schedule**](docs/apis/tags/ConfigurationDeploymentApi.md#update_firmware_upgrade_schedule) | **put** /deployments/{deploymentId} | Update schedule with deployment ID
*ConfigurationNetworkApi* | [**create_network_services**](docs/apis/tags/ConfigurationNetworkApi.md#create_network_services) | **post** /network-services | Create Network Services
*ConfigurationNetworkApi* | [**create_tunnel_concentrator**](docs/apis/tags/ConfigurationNetworkApi.md#create_tunnel_concentrator) | **post** /tunnel-concentrators | Create a Tunnel Concentrator
*ConfigurationNetworkApi* | [**delete_network_service**](docs/apis/tags/ConfigurationNetworkApi.md#delete_network_service) | **delete** /network-services/{id} | Delete Network Services
*ConfigurationNetworkApi* | [**delete_tunnel_concentrator**](docs/apis/tags/ConfigurationNetworkApi.md#delete_tunnel_concentrator) | **delete** /tunnel-concentrators/{id} | Delete TunnelConcentrator by ID
*ConfigurationNetworkApi* | [**get_tunnel_concentrator**](docs/apis/tags/ConfigurationNetworkApi.md#get_tunnel_concentrator) | **get** /tunnel-concentrators/{id} | Get Tunnel Concentrator by ID
*ConfigurationNetworkApi* | [**list_network_services**](docs/apis/tags/ConfigurationNetworkApi.md#list_network_services) | **get** /network-services | List Network Services
*ConfigurationNetworkApi* | [**list_tunnel_concentrators**](docs/apis/tags/ConfigurationNetworkApi.md#list_tunnel_concentrators) | **get** /tunnel-concentrators | List Tunnel Concentrators
*ConfigurationNetworkApi* | [**update_tunnel_concentrator**](docs/apis/tags/ConfigurationNetworkApi.md#update_tunnel_concentrator) | **put** /tunnel-concentrators/{id} | Update TunnelConcentrator by ID
*ConfigurationPolicyApi* | [**attach_client_monitor_profile_to_ssid**](docs/apis/tags/ConfigurationPolicyApi.md#attach_client_monitor_profile_to_ssid) | **post** /ssids/{id}/client-monitor-profile/:attach | Attach client monitor profile to an SSID
*ConfigurationPolicyApi* | [**attach_cwp_to_ssid**](docs/apis/tags/ConfigurationPolicyApi.md#attach_cwp_to_ssid) | **post** /ssids/{id}/cwp/:attach | Attach CWP to an SSID
*ConfigurationPolicyApi* | [**attach_ip_firewall_policy_to_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#attach_ip_firewall_policy_to_user_profile) | **post** /user-profiles/{id}/ip-firewall-policies/:attach | Attach IP Firewall Policy to an User Profile
*ConfigurationPolicyApi* | [**attach_mac_firewall_policy_to_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#attach_mac_firewall_policy_to_user_profile) | **post** /user-profiles/{id}/mac-firewall-policies/:attach | Attach MAC Firewall Policy to an User Profile
*ConfigurationPolicyApi* | [**attach_radius_client_profile_to_ssid**](docs/apis/tags/ConfigurationPolicyApi.md#attach_radius_client_profile_to_ssid) | **post** /ssids/{id}/radius-client-profile/:attach | Attach RADIUS client profile to an SSID
*ConfigurationPolicyApi* | [**attach_radius_server_group_to_ssid**](docs/apis/tags/ConfigurationPolicyApi.md#attach_radius_server_group_to_ssid) | **post** /ssids/{id}/radius-server-group/:attach | Attach radius server group to an SSID
*ConfigurationPolicyApi* | [**attach_service_to_ip_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#attach_service_to_ip_firewall_policy) | **post** /ip-firewall-policies/{id}/ip-firewall-rule/:attach | Attach IP Firewall Rule to IP Firewall policy
*ConfigurationPolicyApi* | [**attach_service_to_mac_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#attach_service_to_mac_firewall_policy) | **post** /mac-firewall-policies/{id}/mac-firewall-rule/:attach | Attach MAC Firewall Rule to MAC Firewall policy
*ConfigurationPolicyApi* | [**attach_user_profile_assignment_to_ssid**](docs/apis/tags/ConfigurationPolicyApi.md#attach_user_profile_assignment_to_ssid) | **post** /ssids/{id}/user-profile-assignment/:attach | Attach user profile assignment to an SSID
*ConfigurationPolicyApi* | [**attach_user_profile_to_ssid**](docs/apis/tags/ConfigurationPolicyApi.md#attach_user_profile_to_ssid) | **post** /ssids/{id}/user-profile/:attach | Attach user profile to an SSID
*ConfigurationPolicyApi* | [**change_psk_password**](docs/apis/tags/ConfigurationPolicyApi.md#change_psk_password) | **put** /ssids/{id}/psk/password | Change the SSID PSK password
*ConfigurationPolicyApi* | [**create_classification_rule**](docs/apis/tags/ConfigurationPolicyApi.md#create_classification_rule) | **post** /classification-rules | Create classification rule
*ConfigurationPolicyApi* | [**create_client_monitor_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_client_monitor_profile) | **post** /client-monitor-profiles | Create a client monitor profile
*ConfigurationPolicyApi* | [**create_cloud_config_group**](docs/apis/tags/ConfigurationPolicyApi.md#create_cloud_config_group) | **post** /ccgs | Create new cloud config group
*ConfigurationPolicyApi* | [**create_hotspot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_hotspot_profile) | **post** /hotspot-profiles | Create a Hotspot profile
*ConfigurationPolicyApi* | [**create_hotspot_service_provider_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_hotspot_service_provider_profile) | **post** /hotspot-service-provider-profiles | Create a Hotspot Service Provider profile
*ConfigurationPolicyApi* | [**create_iot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_iot_profile) | **post** /iot-profiles | Create a IoT profile
*ConfigurationPolicyApi* | [**create_ip_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#create_ip_firewall_policy) | **post** /ip-firewall-policies | Create IP Firewall policy
*ConfigurationPolicyApi* | [**create_l3_address_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_l3_address_profile) | **post** /l3-address-profiles | Create a L3 address profile
*ConfigurationPolicyApi* | [**create_mac_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#create_mac_firewall_policy) | **post** /mac-firewall-policies | Create MAC Firewall policy
*ConfigurationPolicyApi* | [**create_mac_object**](docs/apis/tags/ConfigurationPolicyApi.md#create_mac_object) | **post** /mac-object-profiles | Create a mac object
*ConfigurationPolicyApi* | [**create_mac_oui_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_mac_oui_profile) | **post** /radio-profiles/mac-ouis | Create a MAC OUI profile
*ConfigurationPolicyApi* | [**create_radio_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_radio_profile) | **post** /radio-profiles | Create a radio profile
*ConfigurationPolicyApi* | [**create_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#create_user_profile) | **post** /user-profiles | Create a user profile
*ConfigurationPolicyApi* | [**create_user_profile_assignment**](docs/apis/tags/ConfigurationPolicyApi.md#create_user_profile_assignment) | **post** /user-profile-assignments | Create a user profile assignment
*ConfigurationPolicyApi* | [**delete_classification_rule**](docs/apis/tags/ConfigurationPolicyApi.md#delete_classification_rule) | **delete** /classification-rules/{id} | Delete classification rule by ID
*ConfigurationPolicyApi* | [**delete_client_monitor_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_client_monitor_profile) | **delete** /client-monitor-profiles/{id} | Delete an client monitor profile by ID
*ConfigurationPolicyApi* | [**delete_cloud_config_group**](docs/apis/tags/ConfigurationPolicyApi.md#delete_cloud_config_group) | **delete** /ccgs/{id} | Delete a cloud config group
*ConfigurationPolicyApi* | [**delete_co_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_co_user_profile) | **delete** /user-profiles/{id} | Delete an user profile by ID
*ConfigurationPolicyApi* | [**delete_hotspot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_hotspot_profile) | **delete** /hotspot-profiles/{id} | Delete Hotspot profile by ID
*ConfigurationPolicyApi* | [**delete_hotspot_service_provider_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_hotspot_service_provider_profile) | **delete** /hotspot-service-provider-profiles/{id} | Delete Hotspot Service Provider profile by ID
*ConfigurationPolicyApi* | [**delete_iot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_iot_profile) | **delete** /iot-profiles/{id} | Delete IoT profile by ID
*ConfigurationPolicyApi* | [**delete_ip_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#delete_ip_firewall_policy) | **delete** /ip-firewall-policies/{id} | Delete IP Firewall policy by ID
*ConfigurationPolicyApi* | [**delete_l3_address_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_l3_address_profile) | **delete** /l3-address-profiles/{id} | Delete a L3 address profile by ID
*ConfigurationPolicyApi* | [**delete_mac_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#delete_mac_firewall_policy) | **delete** /mac-firewall-policies/{id} | Delete MAC Firewall policy by ID
*ConfigurationPolicyApi* | [**delete_mac_object_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#delete_mac_object_profiles) | **delete** /mac-object-profiles/{id} | Delete a MAC object by ID
*ConfigurationPolicyApi* | [**delete_radio_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_radio_profile) | **delete** /radio-profiles/{id} | Delete radio profile by ID
*ConfigurationPolicyApi* | [**delete_rp_mac_oui_profile**](docs/apis/tags/ConfigurationPolicyApi.md#delete_rp_mac_oui_profile) | **delete** /radio-profiles/mac-ouis/{id} | Delete MAC OUI profile
*ConfigurationPolicyApi* | [**delete_user_profile_assignment**](docs/apis/tags/ConfigurationPolicyApi.md#delete_user_profile_assignment) | **delete** /user-profile-assignments/{id} | Delete an user profile assignment by ID
*ConfigurationPolicyApi* | [**detach_ip_firewall_policy_from_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#detach_ip_firewall_policy_from_user_profile) | **post** /user-profiles/{id}/ip-firewall-policies/:detach | Detach IP Firewall Policy from an User Profile
*ConfigurationPolicyApi* | [**detach_mac_firewall_policy_from_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#detach_mac_firewall_policy_from_user_profile) | **post** /user-profiles/{id}/mac-firewall-policies/:detach | Detach MAC Firewall Policy from an User Profile
*ConfigurationPolicyApi* | [**detach_service_to_ip_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#detach_service_to_ip_firewall_policy) | **post** /ip-firewall-policies/{id}/ip-firewall-rule/:detach | Detach IP Firewall Rule from IP Firewall policy
*ConfigurationPolicyApi* | [**detach_service_to_mac_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#detach_service_to_mac_firewall_policy) | **post** /mac-firewall-policies/{id}/mac-firewall-rule/:detach | Detach MAC Firewall Rule from MAC Firewall policy
*ConfigurationPolicyApi* | [**disable_ssid_cwp**](docs/apis/tags/ConfigurationPolicyApi.md#disable_ssid_cwp) | **post** /ssids/{id}/cwp/:disable | Disable the CWP on the SSID
*ConfigurationPolicyApi* | [**enable_ssid_cwp**](docs/apis/tags/ConfigurationPolicyApi.md#enable_ssid_cwp) | **post** /ssids/{id}/cwp/:enable | Enable and attach the CWP on the SSID
*ConfigurationPolicyApi* | [**get_classification_rule**](docs/apis/tags/ConfigurationPolicyApi.md#get_classification_rule) | **get** /classification-rules/{id} | Get a classification rule by ID
*ConfigurationPolicyApi* | [**get_client_monitor_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_client_monitor_profile) | **get** /client-monitor-profiles/{id} | Get client monitor profile by ID
*ConfigurationPolicyApi* | [**get_cloud_config_group**](docs/apis/tags/ConfigurationPolicyApi.md#get_cloud_config_group) | **get** /ccgs/{id} | Get a cloud config group
*ConfigurationPolicyApi* | [**get_hotspot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_hotspot_profile) | **get** /hotspot-profiles/{id} | Get Hotspot profile by ID
*ConfigurationPolicyApi* | [**get_hotspot_service_provider_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_hotspot_service_provider_profile) | **get** /hotspot-service-provider-profiles/{id} | Get Hotspot Service Provider profile by ID
*ConfigurationPolicyApi* | [**get_iot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_iot_profile) | **get** /iot-profiles/{id} | Get IoT profile by ID
*ConfigurationPolicyApi* | [**get_ip_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#get_ip_firewall_policy) | **get** /ip-firewall-policies/{id} | Get IP Firewall Policy by ID
*ConfigurationPolicyApi* | [**get_l3_address_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_l3_address_profile) | **get** /l3-address-profiles/{id} | Get a L3 address profile by ID
*ConfigurationPolicyApi* | [**get_mac_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#get_mac_firewall_policy) | **get** /mac-firewall-policies/{id} | Get MAC Firewall Policy by ID
*ConfigurationPolicyApi* | [**get_mac_object**](docs/apis/tags/ConfigurationPolicyApi.md#get_mac_object) | **get** /mac-object-profiles/{id} | Get MAC Object by ID
*ConfigurationPolicyApi* | [**get_neighborhood_analysis**](docs/apis/tags/ConfigurationPolicyApi.md#get_neighborhood_analysis) | **get** /radio-profiles/neighborhood-analysis/{id} | Get neighborhood analysis settings
*ConfigurationPolicyApi* | [**get_radio_operating_modes**](docs/apis/tags/ConfigurationPolicyApi.md#get_radio_operating_modes) | **get** /radio-operating-modes/{productType} | Get Radio Operating Modes by product type
*ConfigurationPolicyApi* | [**get_radio_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_radio_profile) | **get** /radio-profiles/{id} | Get radio profile by ID
*ConfigurationPolicyApi* | [**get_rp_channel_selection**](docs/apis/tags/ConfigurationPolicyApi.md#get_rp_channel_selection) | **get** /radio-profiles/channel-selection/{id} | Get channel selection settings
*ConfigurationPolicyApi* | [**get_rp_mac_oui_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_rp_mac_oui_profile) | **get** /radio-profiles/mac-ouis/{id} | Get MAC OUI profile
*ConfigurationPolicyApi* | [**get_rp_miscellaneous_settings**](docs/apis/tags/ConfigurationPolicyApi.md#get_rp_miscellaneous_settings) | **get** /radio-profiles/miscellaneous/{id} | Get radio miscellaneous settings
*ConfigurationPolicyApi* | [**get_rp_radio_usage_optimization**](docs/apis/tags/ConfigurationPolicyApi.md#get_rp_radio_usage_optimization) | **get** /radio-profiles/radio-usage-opt/{id} | Get radio usage optimization settings
*ConfigurationPolicyApi* | [**get_rp_sensor_scan_settings**](docs/apis/tags/ConfigurationPolicyApi.md#get_rp_sensor_scan_settings) | **get** /radio-profiles/sensor-scan/{id} | Get sensor scan settings
*ConfigurationPolicyApi* | [**get_rp_wmm_qos_settings**](docs/apis/tags/ConfigurationPolicyApi.md#get_rp_wmm_qos_settings) | **get** /radio-profiles/wmm-qos/{id} | Get Wmm QoS settings
*ConfigurationPolicyApi* | [**get_ssid_advanced_settings**](docs/apis/tags/ConfigurationPolicyApi.md#get_ssid_advanced_settings) | **get** /ssids/advanced-settings/{id} | Get SSID advanced settings
*ConfigurationPolicyApi* | [**get_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#get_user_profile) | **get** /user-profiles/{id} | Get user profile by ID
*ConfigurationPolicyApi* | [**get_user_profile_assignment**](docs/apis/tags/ConfigurationPolicyApi.md#get_user_profile_assignment) | **get** /user-profile-assignments/{id} | Get user profile assignment by ID
*ConfigurationPolicyApi* | [**list_classification_rules**](docs/apis/tags/ConfigurationPolicyApi.md#list_classification_rules) | **get** /classification-rules | List classification rules
*ConfigurationPolicyApi* | [**list_client_monitor_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_client_monitor_profiles) | **get** /client-monitor-profiles | List client monitor profiles
*ConfigurationPolicyApi* | [**list_cloud_config_groups**](docs/apis/tags/ConfigurationPolicyApi.md#list_cloud_config_groups) | **get** /ccgs | [LRO] List clould config groups
*ConfigurationPolicyApi* | [**list_hotspot_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_hotspot_profiles) | **get** /hotspot-profiles | List Hotspot profiles
*ConfigurationPolicyApi* | [**list_hotspot_service_provider_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_hotspot_service_provider_profiles) | **get** /hotspot-service-provider-profiles | List Hotspot Service Provider profiles
*ConfigurationPolicyApi* | [**list_iot_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_iot_profiles) | **get** /iot-profiles | List IoT profiles
*ConfigurationPolicyApi* | [**list_ip_firewall_policies**](docs/apis/tags/ConfigurationPolicyApi.md#list_ip_firewall_policies) | **get** /ip-firewall-policies | List IP Firewall policies
*ConfigurationPolicyApi* | [**list_l3_address_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_l3_address_profiles) | **get** /l3-address-profiles | List L3 address profiles
*ConfigurationPolicyApi* | [**list_mac_firewall_policies**](docs/apis/tags/ConfigurationPolicyApi.md#list_mac_firewall_policies) | **get** /mac-firewall-policies | List MAC Firewall policies
*ConfigurationPolicyApi* | [**list_mac_object_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_mac_object_profiles) | **get** /mac-object-profiles | List mac object profiles
*ConfigurationPolicyApi* | [**list_radio_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_radio_profiles) | **get** /radio-profiles | List radio profiles
*ConfigurationPolicyApi* | [**list_rp_mac_oui_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_rp_mac_oui_profiles) | **get** /radio-profiles/mac-ouis | List MAC OUI profiles
*ConfigurationPolicyApi* | [**list_ssids**](docs/apis/tags/ConfigurationPolicyApi.md#list_ssids) | **get** /ssids | List SSIDs
*ConfigurationPolicyApi* | [**list_user_profile_assignments**](docs/apis/tags/ConfigurationPolicyApi.md#list_user_profile_assignments) | **get** /user-profile-assignments | List user profile assignments
*ConfigurationPolicyApi* | [**list_user_profiles**](docs/apis/tags/ConfigurationPolicyApi.md#list_user_profiles) | **get** /user-profiles | List user profiles
*ConfigurationPolicyApi* | [**rename_ssid**](docs/apis/tags/ConfigurationPolicyApi.md#rename_ssid) | **post** /ssids/{id}/:rename | Rename SSID (Wireless name)
*ConfigurationPolicyApi* | [**set_ssid_mode_dot1x**](docs/apis/tags/ConfigurationPolicyApi.md#set_ssid_mode_dot1x) | **put** /ssids/{id}/mode/dot1x | Change the SSID mode to 802.1x
*ConfigurationPolicyApi* | [**set_ssid_mode_open**](docs/apis/tags/ConfigurationPolicyApi.md#set_ssid_mode_open) | **put** /ssids/{id}/mode/open | Change the SSID mode to open access
*ConfigurationPolicyApi* | [**set_ssid_mode_ppsk**](docs/apis/tags/ConfigurationPolicyApi.md#set_ssid_mode_ppsk) | **put** /ssids/{id}/mode/ppsk | Change the SSID mode to PPSK
*ConfigurationPolicyApi* | [**set_ssid_mode_psk**](docs/apis/tags/ConfigurationPolicyApi.md#set_ssid_mode_psk) | **put** /ssids/{id}/mode/psk | Change the SSID mode to PSK
*ConfigurationPolicyApi* | [**set_ssid_mode_wep**](docs/apis/tags/ConfigurationPolicyApi.md#set_ssid_mode_wep) | **put** /ssids/{id}/mode/wep | Change the SSID mode to WEP
*ConfigurationPolicyApi* | [**update_classification_rule**](docs/apis/tags/ConfigurationPolicyApi.md#update_classification_rule) | **put** /classification-rules/{id} | Update classification rule
*ConfigurationPolicyApi* | [**update_client_monitor_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_client_monitor_profile) | **put** /client-monitor-profiles/{id} | Update client monitor profile
*ConfigurationPolicyApi* | [**update_cloud_config_group**](docs/apis/tags/ConfigurationPolicyApi.md#update_cloud_config_group) | **put** /ccgs/{id} | Update cloud config group information
*ConfigurationPolicyApi* | [**update_co_user_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_co_user_profile) | **put** /user-profiles/{id} | Update user profile
*ConfigurationPolicyApi* | [**update_hotspot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_hotspot_profile) | **put** /hotspot-profiles/{id} | Update Hotspot profile by ID
*ConfigurationPolicyApi* | [**update_hotspot_service_provider_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_hotspot_service_provider_profile) | **put** /hotspot-service-provider-profiles/{id} | Update Hotspot Service Provider profile by ID
*ConfigurationPolicyApi* | [**update_iot_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_iot_profile) | **put** /iot-profiles/{id} | Update IoT profile by ID
*ConfigurationPolicyApi* | [**update_ip_policy_request**](docs/apis/tags/ConfigurationPolicyApi.md#update_ip_policy_request) | **put** /ip-firewall-policies/{id} | Update IP Firewall policy by ID
*ConfigurationPolicyApi* | [**update_l3_address_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_l3_address_profile) | **put** /l3-address-profiles/{id} | Update a L3 address profile
*ConfigurationPolicyApi* | [**update_mac_firewall_policy**](docs/apis/tags/ConfigurationPolicyApi.md#update_mac_firewall_policy) | **put** /mac-firewall-policies/{id} | Update MAC Firewall policy by ID
*ConfigurationPolicyApi* | [**update_mac_object**](docs/apis/tags/ConfigurationPolicyApi.md#update_mac_object) | **put** /mac-object-profiles/{id} | Update MAC Object by ID
*ConfigurationPolicyApi* | [**update_neighborhood_analysis**](docs/apis/tags/ConfigurationPolicyApi.md#update_neighborhood_analysis) | **put** /radio-profiles/neighborhood-analysis/{id} | Update neighborhood analysis settings
*ConfigurationPolicyApi* | [**update_radio_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_radio_profile) | **put** /radio-profiles/{id} | Update radio profile by ID
*ConfigurationPolicyApi* | [**update_rp_channel_selection**](docs/apis/tags/ConfigurationPolicyApi.md#update_rp_channel_selection) | **put** /radio-profiles/channel-selection/{id} | Update channel selection settings
*ConfigurationPolicyApi* | [**update_rp_mac_oui_profile**](docs/apis/tags/ConfigurationPolicyApi.md#update_rp_mac_oui_profile) | **put** /radio-profiles/mac-ouis/{id} | Update MAC OUI profile
*ConfigurationPolicyApi* | [**update_rp_miscellaneous_settings**](docs/apis/tags/ConfigurationPolicyApi.md#update_rp_miscellaneous_settings) | **put** /radio-profiles/miscellaneous/{id} | Update radio miscellaneous settings
*ConfigurationPolicyApi* | [**update_rp_radio_usage_optimization**](docs/apis/tags/ConfigurationPolicyApi.md#update_rp_radio_usage_optimization) | **put** /radio-profiles/radio-usage-opt/{id} | Update radio usage optimization settings
*ConfigurationPolicyApi* | [**update_rp_sensor_scan_settings**](docs/apis/tags/ConfigurationPolicyApi.md#update_rp_sensor_scan_settings) | **put** /radio-profiles/sensor-scan/{id} | Update sensor scan settings
*ConfigurationPolicyApi* | [**update_rp_wmm_qos_settings**](docs/apis/tags/ConfigurationPolicyApi.md#update_rp_wmm_qos_settings) | **put** /radio-profiles/wmm-qos/{id} | Update Wmm QoS settings
*ConfigurationPolicyApi* | [**update_ssid_advanced_settings**](docs/apis/tags/ConfigurationPolicyApi.md#update_ssid_advanced_settings) | **put** /ssids/advanced-settings/{id} | Update SSID advanced settings
*ConfigurationUserManagementApi* | [**add_key_based_pcg_users**](docs/apis/tags/ConfigurationUserManagementApi.md#add_key_based_pcg_users) | **post** /pcgs/key-based/network-policy-{policyId}/users | [LRO] Add users to a PCG-enabled network policy
*ConfigurationUserManagementApi* | [**assign_ports**](docs/apis/tags/ConfigurationUserManagementApi.md#assign_ports) | **post** /pcgs/key-based/network-policy-{policyId}/port-assignments | Assign ports to devices in network policy
*ConfigurationUserManagementApi* | [**create_end_user**](docs/apis/tags/ConfigurationUserManagementApi.md#create_end_user) | **post** /endusers | Create an end user
*ConfigurationUserManagementApi* | [**create_key_based_pcg_network_policy**](docs/apis/tags/ConfigurationUserManagementApi.md#create_key_based_pcg_network_policy) | **post** /pcgs/key-based | [LRO] Create a Key-based Private Client Group
*ConfigurationUserManagementApi* | [**create_user_group**](docs/apis/tags/ConfigurationUserManagementApi.md#create_user_group) | **post** /usergroups | Create user group
*ConfigurationUserManagementApi* | [**delete_key_based_pcg_users**](docs/apis/tags/ConfigurationUserManagementApi.md#delete_key_based_pcg_users) | **delete** /pcgs/key-based/network-policy-{policyId}/users | Delete users from a PCG-enabled network policy
*ConfigurationUserManagementApi* | [**delete_pcg**](docs/apis/tags/ConfigurationUserManagementApi.md#delete_pcg) | **delete** /pcgs/key-based/network-policy-{policyId} | Delete Private Client Group from a network policy
*ConfigurationUserManagementApi* | [**delete_ssid_user**](docs/apis/tags/ConfigurationUserManagementApi.md#delete_ssid_user) | **delete** /endusers/{id} | Delete end user by ID
*ConfigurationUserManagementApi* | [**delete_user_group**](docs/apis/tags/ConfigurationUserManagementApi.md#delete_user_group) | **delete** /usergroups/{id} | Delete user group by ID
*ConfigurationUserManagementApi* | [**email_keys**](docs/apis/tags/ConfigurationUserManagementApi.md#email_keys) | **post** /pcgs/key-based/network-policy-{policyId}/keys/:email | Send keys to users in network policy via Email
*ConfigurationUserManagementApi* | [**generate_keys**](docs/apis/tags/ConfigurationUserManagementApi.md#generate_keys) | **post** /pcgs/key-based/network-policy-{policyId}/keys/:generate | Generate shared keys for users in network policy
*ConfigurationUserManagementApi* | [**get_key_based_pcg_users**](docs/apis/tags/ConfigurationUserManagementApi.md#get_key_based_pcg_users) | **get** /pcgs/key-based/network-policy-{policyId}/users | Get users for a PCG-enabled network policy
*ConfigurationUserManagementApi* | [**get_port_assignments**](docs/apis/tags/ConfigurationUserManagementApi.md#get_port_assignments) | **get** /pcgs/key-based/network-policy-{policyId}/port-assignments | Get device port assignments in network policy
*ConfigurationUserManagementApi* | [**list_email_templates**](docs/apis/tags/ConfigurationUserManagementApi.md#list_email_templates) | **get** /email-templates | List Email templates
*ConfigurationUserManagementApi* | [**list_end_users**](docs/apis/tags/ConfigurationUserManagementApi.md#list_end_users) | **get** /endusers | List end users
*ConfigurationUserManagementApi* | [**list_key_based_private_client_groups**](docs/apis/tags/ConfigurationUserManagementApi.md#list_key_based_private_client_groups) | **get** /pcgs/key-based | List Key-based Private Client Groups
*ConfigurationUserManagementApi* | [**list_sms_templates**](docs/apis/tags/ConfigurationUserManagementApi.md#list_sms_templates) | **get** /sms-templates | List SMS templates
*ConfigurationUserManagementApi* | [**list_unique_user_group_names**](docs/apis/tags/ConfigurationUserManagementApi.md#list_unique_user_group_names) | **get** /usergroups/:unique | List unique user group names
*ConfigurationUserManagementApi* | [**list_user_groups**](docs/apis/tags/ConfigurationUserManagementApi.md#list_user_groups) | **get** /usergroups | List user groups
*ConfigurationUserManagementApi* | [**onboard_key_based_private_client_group**](docs/apis/tags/ConfigurationUserManagementApi.md#onboard_key_based_private_client_group) | **post** /pcgs/key-based/network-policy-{policyId}/:onboard | [LRO] Onboard Key-based PCG in network policy
*ConfigurationUserManagementApi* | [**regenerate_end_user_password**](docs/apis/tags/ConfigurationUserManagementApi.md#regenerate_end_user_password) | **post** /endusers/{id}/:regenerate-password | Regenerate a new password for the end user
*ConfigurationUserManagementApi* | [**update_end_user**](docs/apis/tags/ConfigurationUserManagementApi.md#update_end_user) | **put** /endusers/{id} | Update an end user
*ConfigurationUserManagementApi* | [**update_key_based_pcg_users**](docs/apis/tags/ConfigurationUserManagementApi.md#update_key_based_pcg_users) | **put** /pcgs/key-based/network-policy-{policyId}/users | Replace all users in a PCG-enabled network policy
*ConfigurationUserManagementApi* | [**update_user_group**](docs/apis/tags/ConfigurationUserManagementApi.md#update_user_group) | **put** /usergroups/{id} | Update user group
*CopilotAnomaliesApi* | [**get_anomalies_notifications**](docs/apis/tags/CopilotAnomaliesApi.md#get_anomalies_notifications) | **get** /copilot/anomalies/notifications | 
*CopilotAnomaliesApi* | [**get_anomalies_report**](docs/apis/tags/CopilotAnomaliesApi.md#get_anomalies_report) | **get** /copilot/anomalies/report | 
*CopilotAnomaliesApi* | [**get_assurance_scans_overview_data**](docs/apis/tags/CopilotAnomaliesApi.md#get_assurance_scans_overview_data) | **get** /copilot/assurance-scans/overview | 
*CopilotAnomaliesApi* | [**get_atp_device_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_atp_device_stats) | **get** /copilot/anomalies/adverse-traffic/device-stats | 
*CopilotAnomaliesApi* | [**get_atp_packet_counts**](docs/apis/tags/CopilotAnomaliesApi.md#get_atp_packet_counts) | **get** /copilot/anomalies/adverse-traffic/packet-counts | 
*CopilotAnomaliesApi* | [**get_copilot_anomaliesby_category**](docs/apis/tags/CopilotAnomaliesApi.md#get_copilot_anomaliesby_category) | **get** /copilot/anomalies/anomalies-by-category | 
*CopilotAnomaliesApi* | [**get_copilot_devices_with_locations**](docs/apis/tags/CopilotAnomaliesApi.md#get_copilot_devices_with_locations) | **get** /copilot/anomalies/devices-with-locations | 
*CopilotAnomaliesApi* | [**get_devices_by_location**](docs/apis/tags/CopilotAnomaliesApi.md#get_devices_by_location) | **get** /copilot/anomalies/devices-by-location | 
*CopilotAnomaliesApi* | [**get_dfs_recurrence_channel_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_dfs_recurrence_channel_stats) | **get** /copilot/anomalies/dfs-recurrence/channel-stats | 
*CopilotAnomaliesApi* | [**get_dfs_recurrence_count_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_dfs_recurrence_count_stats) | **get** /copilot/anomalies/dfs-recurrence/count-stats | 
*CopilotAnomaliesApi* | [**get_hardware_health_client_list**](docs/apis/tags/CopilotAnomaliesApi.md#get_hardware_health_client_list) | **get** /copilot/anomalies/hardware-health/client-list | 
*CopilotAnomaliesApi* | [**get_hardware_health_cpu_mem_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_hardware_health_cpu_mem_stats) | **get** /copilot/anomalies/hardware-health/cpu-mem-stats | 
*CopilotAnomaliesApi* | [**get_hardware_health_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_hardware_health_stats) | **get** /copilot/anomalies/hardware-health/stats | 
*CopilotAnomaliesApi* | [**get_lldp_cdp_info**](docs/apis/tags/CopilotAnomaliesApi.md#get_lldp_cdp_info) | **get** /copilot/anomalies/poeflapping/lldp-cdp-info | 
*CopilotAnomaliesApi* | [**get_missing_vlan_anomalies_count**](docs/apis/tags/CopilotAnomaliesApi.md#get_missing_vlan_anomalies_count) | **get** /copilot/anomalies/missing-vlan/count | 
*CopilotAnomaliesApi* | [**get_missing_vlan_excluded_vlan_list**](docs/apis/tags/CopilotAnomaliesApi.md#get_missing_vlan_excluded_vlan_list) | **get** /copilot/anomalies/excluded-vlans-list | 
*CopilotAnomaliesApi* | [**get_poe_flapping_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_poe_flapping_stats) | **get** /copilot/anomalies/poeflapping/stats | 
*CopilotAnomaliesApi* | [**get_poe_flapping_trends**](docs/apis/tags/CopilotAnomaliesApi.md#get_poe_flapping_trends) | **get** /copilot/anomalies/poeflapping/trends | 
*CopilotAnomaliesApi* | [**get_port_efficiency_speed_duplex_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_port_efficiency_speed_duplex_stats) | **get** /copilot/anomalies/port-efficiency/speed-duplex-stats | 
*CopilotAnomaliesApi* | [**get_port_efficiency_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_port_efficiency_stats) | **get** /copilot/anomalies/port-efficiency/stats | 
*CopilotAnomaliesApi* | [**get_wifi_capacity_client_list**](docs/apis/tags/CopilotAnomaliesApi.md#get_wifi_capacity_client_list) | **get** /copilot/anomalies/wifi-capacity/client-list | 
*CopilotAnomaliesApi* | [**get_wifi_capacity_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_wifi_capacity_stats) | **get** /copilot/anomalies/wifi-capacity/stats | 
*CopilotAnomaliesApi* | [**get_wifi_efficiency_client_list**](docs/apis/tags/CopilotAnomaliesApi.md#get_wifi_efficiency_client_list) | **get** /copilot/anomalies/wifi-efficiency/client-list | 
*CopilotAnomaliesApi* | [**get_wifi_efficiency_stats**](docs/apis/tags/CopilotAnomaliesApi.md#get_wifi_efficiency_stats) | **get** /copilot/anomalies/wifi-efficiency/stats | 
*CopilotAnomaliesApi* | [**list_anomaly_locations**](docs/apis/tags/CopilotAnomaliesApi.md#list_anomaly_locations) | **get** /copilot/anomalies/locations | 
*CopilotAnomaliesApi* | [**update_anomalies_feedback**](docs/apis/tags/CopilotAnomaliesApi.md#update_anomalies_feedback) | **put** /copilot/anomalies/devices/feedback | 
*CopilotAnomaliesApi* | [**update_anomaly_action**](docs/apis/tags/CopilotAnomaliesApi.md#update_anomaly_action) | **put** /copilot/anomalies/update-action | 
*CopilotAnomaliesApi* | [**update_anomaly_device_action**](docs/apis/tags/CopilotAnomaliesApi.md#update_anomaly_device_action) | **put** /copilot/anomalies/devices/update-action | 
*CopilotAnomaliesApi* | [**update_copilot_anomalies_devices_action**](docs/apis/tags/CopilotAnomaliesApi.md#update_copilot_anomalies_devices_action) | **put** /copilot/anomalies/update-device-action | [LRO] Update Anomalies and Devices
*CopilotAnomaliesApi* | [**update_missing_vlan_excluded_vlan_csv**](docs/apis/tags/CopilotAnomaliesApi.md#update_missing_vlan_excluded_vlan_csv) | **post** /copilot/anomalies/exclude-vlans-csv | 
*CopilotAnomaliesApi* | [**update_missing_vlan_excluded_vlan_list**](docs/apis/tags/CopilotAnomaliesApi.md#update_missing_vlan_excluded_vlan_list) | **post** /copilot/anomalies/exclude-vlans | 
*CopilotConnectivityExperienceApi* | [**get_connectivity_details_by_client_type**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_connectivity_details_by_client_type) | **get** /copilot/connectivity/client-type | 
*CopilotConnectivityExperienceApi* | [**get_connectivity_details_by_locations**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_connectivity_details_by_locations) | **get** /copilot/connectivity/locations | 
*CopilotConnectivityExperienceApi* | [**get_wired_connectivity_experience**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wired_connectivity_experience) | **get** /copilot/connectivity/wired/experience | 
*CopilotConnectivityExperienceApi* | [**get_wired_events**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wired_events) | **get** /copilot/connectivity/wired/events | 
*CopilotConnectivityExperienceApi* | [**get_wired_hardware**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wired_hardware) | **get** /copilot/connectivity/wired/hardware | 
*CopilotConnectivityExperienceApi* | [**get_wired_hardware_by_location**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wired_hardware_by_location) | **get** /copilot/connectivity/wired/locations/hardware | 
*CopilotConnectivityExperienceApi* | [**get_wired_quality_index**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wired_quality_index) | **get** /copilot/connectivity/wired/quality-index | 
*CopilotConnectivityExperienceApi* | [**get_wireless_apps**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_apps) | **get** /copilot/connectivity/wireless/apps | 
*CopilotConnectivityExperienceApi* | [**get_wireless_connectivity_experience**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_connectivity_experience) | **get** /copilot/connectivity/wireless/experience | 
*CopilotConnectivityExperienceApi* | [**get_wireless_events**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_events) | **get** /copilot/connectivity/wireless/events | 
*CopilotConnectivityExperienceApi* | [**get_wireless_events_by_location**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_events_by_location) | **get** /copilot/connectivity/wireless/locations/events | 
*CopilotConnectivityExperienceApi* | [**get_wireless_performance**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_performance) | **get** /copilot/connectivity/wireless/performance | 
*CopilotConnectivityExperienceApi* | [**get_wireless_performance_by_location**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_performance_by_location) | **get** /copilot/connectivity/wireless/locations/performance | 
*CopilotConnectivityExperienceApi* | [**get_wireless_quality_index**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_quality_index) | **get** /copilot/connectivity/wireless/quality-index | 
*CopilotConnectivityExperienceApi* | [**get_wireless_quality_index_by_location**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_quality_index_by_location) | **get** /copilot/connectivity/wireless/locations/quality-index | 
*CopilotConnectivityExperienceApi* | [**get_wireless_time_to_connect**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_time_to_connect) | **get** /copilot/connectivity/wireless/time-to-connect | 
*CopilotConnectivityExperienceApi* | [**get_wireless_time_to_connect_by_location**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_time_to_connect_by_location) | **get** /copilot/connectivity/wireless/locations/time-to-connect | 
*CopilotConnectivityExperienceApi* | [**get_wireless_views**](docs/apis/tags/CopilotConnectivityExperienceApi.md#get_wireless_views) | **get** /copilot/connectivity/wireless/views | 
*D360Api* | [**get_client_graph**](docs/apis/tags/D360Api.md#get_client_graph) | **post** /d360/client/graph | List a list of connected clients for Device 360 API
*D360Api* | [**get_client_grid_metadata**](docs/apis/tags/D360Api.md#get_client_grid_metadata) | **get** /d360/client/grid/metadata | Get Client Grid Filter Metadata
*D360Api* | [**get_client_stats**](docs/apis/tags/D360Api.md#get_client_stats) | **get** /d360/client/stats | Get Client Stats Information
*D360Api* | [**get_client_stats_grid**](docs/apis/tags/D360Api.md#get_client_stats_grid) | **post** /d360/client/grid | Get Client Grid
*D360Api* | [**get_device_issues**](docs/apis/tags/D360Api.md#get_device_issues) | **get** /d360/device/issues | Get Device Issues
*D360Api* | [**get_device_meta_data**](docs/apis/tags/D360Api.md#get_device_meta_data) | **get** /d360/device/metadata | Get Device MetaData
*D360Api* | [**get_device_stats1**](docs/apis/tags/D360Api.md#get_device_stats1) | **get** /d360/device/stats | Get Device Stats
*D360Api* | [**get_device_summary1**](docs/apis/tags/D360Api.md#get_device_summary1) | **get** /d360/overview/devices-summary | List the summary of device details
*D360Api* | [**get_ssid_metadata**](docs/apis/tags/D360Api.md#get_ssid_metadata) | **get** /d360/ssid-metadata | Get SSID Metadata
*D360Api* | [**get_surrounding_aps**](docs/apis/tags/D360Api.md#get_surrounding_aps) | **post** /d360/wireless/surrounding-aps | Get a list of SurroundingAps
*D360Api* | [**get_wifi_interface_per_device**](docs/apis/tags/D360Api.md#get_wifi_interface_per_device) | **get** /d360/device/interfaces | Get Wifi Interfaces Per Device Information
*D360Api* | [**get_wireless_interface_graph**](docs/apis/tags/D360Api.md#get_wireless_interface_graph) | **get** /d360/wireless/interfaces-graph | Get Wireless Interface Graph
*D360Api* | [**get_wireless_wifi**](docs/apis/tags/D360Api.md#get_wireless_wifi) | **get** /d360/wireless/interfaces-stats | Get Wifi Information
*DashboardApi* | [**create_wireless_diagnostics_criteria_param**](docs/apis/tags/DashboardApi.md#create_wireless_diagnostics_criteria_param) | **post** /dashboard/wireless/dashboard/criteria | Create Criteria for Wireless Diagnostics Dashboard
*DashboardApi* | [**export_to_csv3**](docs/apis/tags/DashboardApi.md#export_to_csv3) | **post** /dashboard/export | Export all dashboard data to CSV
*DashboardApi* | [**get_alert_diagnostics**](docs/apis/tags/DashboardApi.md#get_alert_diagnostics) | **post** /dashboard/alerts | Alert statistics
*DashboardApi* | [**get_all_diagnostics_device_types**](docs/apis/tags/DashboardApi.md#get_all_diagnostics_device_types) | **get** /dashboard/device-types | Get all diagnostics device types
*DashboardApi* | [**get_asset_diagnostics**](docs/apis/tags/DashboardApi.md#get_asset_diagnostics) | **post** /dashboard/assets | Asset statistics
*DashboardApi* | [**get_client_health_diagnostics**](docs/apis/tags/DashboardApi.md#get_client_health_diagnostics) | **post** /dashboard/clients | Client health statistics
*DashboardApi* | [**get_device_health_diagnostics**](docs/apis/tags/DashboardApi.md#get_device_health_diagnostics) | **post** /dashboard/devices | Device health statistics
*DashboardApi* | [**get_sites_with_issues_diagnostics**](docs/apis/tags/DashboardApi.md#get_sites_with_issues_diagnostics) | **post** /dashboard/sites-with-issues | Sites with issues
*DashboardApi* | [**get_usage_and_capacity_diagnostics**](docs/apis/tags/DashboardApi.md#get_usage_and_capacity_diagnostics) | **post** /dashboard/usage-capacity | Usage &amp; capacity statistics
*DashboardApi* | [**get_wireless_diagnostics_dashboard_criteria_param**](docs/apis/tags/DashboardApi.md#get_wireless_diagnostics_dashboard_criteria_param) | **get** /dashboard/wireless/dashboard/criteria | Criteria for Wireless Diagnostics Dashboard
*DashboardWirelessClientHealthApi* | [**export_to_csv2**](docs/apis/tags/DashboardWirelessClientHealthApi.md#export_to_csv2) | **post** /dashboard/wireless/client-health/export | Export all Client Health Data to CSV
*DashboardWirelessClientHealthApi* | [**get_client_association_issues**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_association_issues) | **post** /dashboard/wireless/client-health/issue/association | Association issue for wireless client
*DashboardWirelessClientHealthApi* | [**get_client_auth_issues**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_auth_issues) | **post** /dashboard/wireless/client-health/issue/authentication | Authentication issue for wireless client
*DashboardWirelessClientHealthApi* | [**get_client_frequency_distribution**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_frequency_distribution) | **post** /dashboard/wireless/client-health/frequency-distribution | Wireless clients count with frequency distribution
*DashboardWirelessClientHealthApi* | [**get_client_health_connectivity_issues**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_health_connectivity_issues) | **post** /dashboard/wireless/client-health/connectivity-issues | Wireless clients count with connectivity issues
*DashboardWirelessClientHealthApi* | [**get_client_health_grid**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_health_grid) | **post** /dashboard/wireless/client-health/grid | Wireless client health grid
*DashboardWirelessClientHealthApi* | [**get_client_health_grid_filter_metadata**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_health_grid_filter_metadata) | **post** /dashboard/wireless/client-health/filter-metadata | 
*DashboardWirelessClientHealthApi* | [**get_client_health_roaming_issues**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_health_roaming_issues) | **post** /dashboard/wireless/client-health/roaming-issues | Wireless clients count with roaming issues
*DashboardWirelessClientHealthApi* | [**get_client_ip_address_issues**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_ip_address_issues) | **post** /dashboard/wireless/client-health/issue/ipaddress | Ip Address issue for Wireless client
*DashboardWirelessClientHealthApi* | [**get_client_roaming_issues**](docs/apis/tags/DashboardWirelessClientHealthApi.md#get_client_roaming_issues) | **post** /dashboard/wireless/client-health/issue/roaming | Roaming issue for wireless client
*DashboardWirelessDeviceHealthApi* | [**export_to_csv1**](docs/apis/tags/DashboardWirelessDeviceHealthApi.md#export_to_csv1) | **post** /dashboard/wireless/device-health/export | Export all Wireless Device Health Data to CSV
*DashboardWirelessDeviceHealthApi* | [**get_device_cpu_usage_issue_count**](docs/apis/tags/DashboardWirelessDeviceHealthApi.md#get_device_cpu_usage_issue_count) | **post** /dashboard/wireless/device-health/issues/cpu-usage-issues | CPU usage issues for wireless devices
*DashboardWirelessDeviceHealthApi* | [**get_device_health_grid**](docs/apis/tags/DashboardWirelessDeviceHealthApi.md#get_device_health_grid) | **post** /dashboard/wireless/device-health/grid | Wireless device health grid
*DashboardWirelessDeviceHealthApi* | [**get_device_memory_usage_issue_count**](docs/apis/tags/DashboardWirelessDeviceHealthApi.md#get_device_memory_usage_issue_count) | **post** /dashboard/wireless/device-health/issues/memory-usage-issues | Memory usage issues for wireless devices
*DashboardWirelessDeviceHealthApi* | [**get_device_poe_usage_issues_count**](docs/apis/tags/DashboardWirelessDeviceHealthApi.md#get_device_poe_usage_issues_count) | **post** /dashboard/wireless/device-health/issues/poe-usage-issues | PoE usage issues for wireless devices
*DashboardWirelessDeviceHealthApi* | [**get_device_reboot_summary**](docs/apis/tags/DashboardWirelessDeviceHealthApi.md#get_device_reboot_summary) | **get** /dashboard/wireless/device-health/reboot/summary | 
*DashboardWirelessDeviceHealthApi* | [**get_device_summary**](docs/apis/tags/DashboardWirelessDeviceHealthApi.md#get_device_summary) | **post** /dashboard/wireless/device-health/summary | Device health summary for wireless devices
*DashboardWirelessUsageAndCapacityApi* | [**export_to_csv**](docs/apis/tags/DashboardWirelessUsageAndCapacityApi.md#export_to_csv) | **post** /dashboard/wireless/usage-capacity/export | Export all Wireless Usage Capacity Data to CSV
*DashboardWirelessUsageAndCapacityApi* | [**get_count_excessive_retries**](docs/apis/tags/DashboardWirelessUsageAndCapacityApi.md#get_count_excessive_retries) | **post** /dashboard/wireless/usage-capacity/excessive-retries | Count of APs with excessive retries
*DashboardWirelessUsageAndCapacityApi* | [**get_packet_loss_excessive_response**](docs/apis/tags/DashboardWirelessUsageAndCapacityApi.md#get_packet_loss_excessive_response) | **post** /dashboard/wireless/usage-capacity/excessive-packet-loss | Count of APs with excessive packet loss
*DashboardWirelessUsageAndCapacityApi* | [**get_usage_capacity_grid**](docs/apis/tags/DashboardWirelessUsageAndCapacityApi.md#get_usage_capacity_grid) | **post** /dashboard/wireless/usage-capacity/grid | Wireless usage &amp; capacity grid
*DashboardWirelessUsageAndCapacityApi* | [**get_wireless_usage_capacity_excessive_utilization**](docs/apis/tags/DashboardWirelessUsageAndCapacityApi.md#get_wireless_usage_capacity_excessive_utilization) | **post** /dashboard/wireless/usage-capacity/excessive-utilization | Count of APs with excessive utilization
*DeviceApi* | [**advanced_onboard_devices**](docs/apis/tags/DeviceApi.md#advanced_onboard_devices) | **post** /devices/:advanced-onboard | [LRO] Advanced Onboard Devices
*DeviceApi* | [**assign_device_client_monitor**](docs/apis/tags/DeviceApi.md#assign_device_client_monitor) | **put** /devices/{id}/client-monitor | Assign client monitor setting to a device
*DeviceApi* | [**assign_device_location**](docs/apis/tags/DeviceApi.md#assign_device_location) | **put** /devices/{id}/location | Assign location to a device
*DeviceApi* | [**assign_device_network_policy**](docs/apis/tags/DeviceApi.md#assign_device_network_policy) | **put** /devices/{id}/network-policy | Assign network policy to a device
*DeviceApi* | [**assign_devices_client_monitor**](docs/apis/tags/DeviceApi.md#assign_devices_client_monitor) | **post** /devices/client-monitor/:assign | Assign client monitor setting to multiple devices
*DeviceApi* | [**assign_devices_country_code**](docs/apis/tags/DeviceApi.md#assign_devices_country_code) | **post** /devices/country-code/:assign | Assign a country code to devices
*DeviceApi* | [**assign_devices_location**](docs/apis/tags/DeviceApi.md#assign_devices_location) | **post** /devices/location/:assign | Assign location to multiple devices
*DeviceApi* | [**assign_devices_network_policy**](docs/apis/tags/DeviceApi.md#assign_devices_network_policy) | **post** /devices/network-policy/:assign | Assign network policy to multiple devices
*DeviceApi* | [**assign_devices_radius_proxy**](docs/apis/tags/DeviceApi.md#assign_devices_radius_proxy) | **put** /devices/radius-proxy/:assign | Assign RADIUS proxy to devices
*DeviceApi* | [**bounce_device_port**](docs/apis/tags/DeviceApi.md#bounce_device_port) | **post** /devices/{id}/bounce-port | Bounce port of a device (EXOS, VOSS and SR Switches
*DeviceApi* | [**change_device_description**](docs/apis/tags/DeviceApi.md#change_device_description) | **put** /devices/{id}/description | Change description for a device
*DeviceApi* | [**change_device_level_ssid_status**](docs/apis/tags/DeviceApi.md#change_device_level_ssid_status) | **post** /devices/{id}/ssid/status/:change | Enable or disable SSID for a device
*DeviceApi* | [**change_device_status_to_manage**](docs/apis/tags/DeviceApi.md#change_device_status_to_manage) | **post** /devices/{id}/:manage | Change admin state to &#x27;Managed&#x27; for a device
*DeviceApi* | [**change_device_status_to_unmanage**](docs/apis/tags/DeviceApi.md#change_device_status_to_unmanage) | **post** /devices/{id}/:unmanage | Change admin state to &#x27;Unmanaged&#x27; for a device
*DeviceApi* | [**change_devices_ibeacon**](docs/apis/tags/DeviceApi.md#change_devices_ibeacon) | **put** /devices/ibeacon | Change iBeacon settings for devices
*DeviceApi* | [**change_devices_os_mode**](docs/apis/tags/DeviceApi.md#change_devices_os_mode) | **post** /devices/os/:change | Change device OS mode
*DeviceApi* | [**change_hostname**](docs/apis/tags/DeviceApi.md#change_hostname) | **put** /devices/{id}/hostname | Change hostname for a device
*DeviceApi* | [**change_status_to_manage**](docs/apis/tags/DeviceApi.md#change_status_to_manage) | **post** /devices/:manage | Change status to Managed
*DeviceApi* | [**change_status_to_unmanage**](docs/apis/tags/DeviceApi.md#change_status_to_unmanage) | **post** /devices/:unmanage | Change status to Unmanaged
*DeviceApi* | [**check_device_ownership**](docs/apis/tags/DeviceApi.md#check_device_ownership) | **post** /devices/:check-ownership | Check caller is allowed to access the device
*DeviceApi* | [**configure_device_radio_operating_mode**](docs/apis/tags/DeviceApi.md#configure_device_radio_operating_mode) | **put** /devices/{id}/radio-operating-mode | Configure radio operating mode of a device
*DeviceApi* | [**configure_ftm_settings**](docs/apis/tags/DeviceApi.md#configure_ftm_settings) | **put** /devices/{id}/ftm-settings | Configure (create / update) device FTM Settings
*DeviceApi* | [**delete_device**](docs/apis/tags/DeviceApi.md#delete_device) | **delete** /devices/{id} | Delete a device
*DeviceApi* | [**delete_devices**](docs/apis/tags/DeviceApi.md#delete_devices) | **post** /devices/:delete | Delete devices
*DeviceApi* | [**delete_ftm_settings**](docs/apis/tags/DeviceApi.md#delete_ftm_settings) | **delete** /devices/{id}/ftm-settings | Delete FTM Settings by device ID
*DeviceApi* | [**disable_iot_on_device**](docs/apis/tags/DeviceApi.md#disable_iot_on_device) | **post** /devices/{id}/iot/:disable | Disable IoT Wireless Interface settings on device
*DeviceApi* | [**download_device_gallery_image**](docs/apis/tags/DeviceApi.md#download_device_gallery_image) | **get** /devices/{id}/gallery-image | Download device gallery image.
*DeviceApi* | [**enable_iot_on_device**](docs/apis/tags/DeviceApi.md#enable_iot_on_device) | **post** /devices/{id}/iot/:enable | Enable IoT Wireless Interface settings on device
*DeviceApi* | [**export_rm_devices_to_csv**](docs/apis/tags/DeviceApi.md#export_rm_devices_to_csv) | **post** /devices/rm-devices-page/export | Export RM devices data to CSV
*DeviceApi* | [**get_device1**](docs/apis/tags/DeviceApi.md#get_device1) | **get** /devices/{id} | Get device info for a specific device
*DeviceApi* | [**get_device_client_monitor**](docs/apis/tags/DeviceApi.md#get_device_client_monitor) | **get** /devices/{id}/client-monitor | Get client monitor setting for a device
*DeviceApi* | [**get_device_connection_status**](docs/apis/tags/DeviceApi.md#get_device_connection_status) | **post** /devices/rm-devices-connection-status | Get Device Connection Status
*DeviceApi* | [**get_device_cpu_memory_history**](docs/apis/tags/DeviceApi.md#get_device_cpu_memory_history) | **get** /devices/{id}/history/cpu-mem | Get device CPU/memory usage history
*DeviceApi* | [**get_device_geolocation**](docs/apis/tags/DeviceApi.md#get_device_geolocation) | **get** /devices/{id}/geolocation | Get Geolocation for a device
*DeviceApi* | [**get_device_ibeacon**](docs/apis/tags/DeviceApi.md#get_device_ibeacon) | **get** /devices/{id}/ibeacon | Get the device iBeacon setting
*DeviceApi* | [**get_device_iot**](docs/apis/tags/DeviceApi.md#get_device_iot) | **get** /devices/{id}/iot | Get the device IoT Wireless Interface settings
*DeviceApi* | [**get_device_level_ssid_status**](docs/apis/tags/DeviceApi.md#get_device_level_ssid_status) | **get** /devices/{id}/ssid/status | Get SSID status for a device
*DeviceApi* | [**get_device_list_metadata**](docs/apis/tags/DeviceApi.md#get_device_list_metadata) | **post** /devices/rm-devices-metadata | Get Device List Metadata
*DeviceApi* | [**get_device_location**](docs/apis/tags/DeviceApi.md#get_device_location) | **get** /devices/{id}/location | Get location for a device
*DeviceApi* | [**get_device_network_policy**](docs/apis/tags/DeviceApi.md#get_device_network_policy) | **get** /devices/{id}/network-policy | Get network policy for a device
*DeviceApi* | [**get_device_radio_operating_mode**](docs/apis/tags/DeviceApi.md#get_device_radio_operating_mode) | **get** /devices/{id}/radio-operating-mode | Get the device radio operating mode
*DeviceApi* | [**get_device_stats**](docs/apis/tags/DeviceApi.md#get_device_stats) | **get** /devices/stats | Get device stats
*DeviceApi* | [**get_device_wifi_interface**](docs/apis/tags/DeviceApi.md#get_device_wifi_interface) | **get** /devices/{id}/interfaces/wifi | Get the device WiFi interfaces stats
*DeviceApi* | [**get_ftm_settings**](docs/apis/tags/DeviceApi.md#get_ftm_settings) | **get** /devices/{id}/ftm-settings | Get FTM Settings by device ID
*DeviceApi* | [**get_stack_member_info**](docs/apis/tags/DeviceApi.md#get_stack_member_info) | **get** /devices/rm-devices-stack/{stackId} | Get Stack Member Info for a given stack id
*DeviceApi* | [**get_xiq_device_installation_report**](docs/apis/tags/DeviceApi.md#get_xiq_device_installation_report) | **get** /devices/{id}/installation-report | Get device installation report
*DeviceApi* | [**list_device_alarm**](docs/apis/tags/DeviceApi.md#list_device_alarm) | **get** /devices/{id}/alarms | List alarms for a device
*DeviceApi* | [**list_devices**](docs/apis/tags/DeviceApi.md#list_devices) | **get** /devices | [LRO] List devices
*DeviceApi* | [**list_devices_by_network_policy**](docs/apis/tags/DeviceApi.md#list_devices_by_network_policy) | **get** /devices/network-policy/{policyId} | List assigned devices for network policy
*DeviceApi* | [**list_devices_radio_information**](docs/apis/tags/DeviceApi.md#list_devices_radio_information) | **get** /devices/radio-information | Get Devices Radio Information
*DeviceApi* | [**list_digital_twin_products**](docs/apis/tags/DeviceApi.md#list_digital_twin_products) | **get** /devices/digital-twin | List Digital Twin product information.
*DeviceApi* | [**monitor_refresh_device**](docs/apis/tags/DeviceApi.md#monitor_refresh_device) | **post** /devices/{id}/monitor/:refresh | Monitor refresh a device
*DeviceApi* | [**monitor_refresh_device_status**](docs/apis/tags/DeviceApi.md#monitor_refresh_device_status) | **get** /devices/{id}/monitor/refresh/status | Monitor refresh a device status 
*DeviceApi* | [**onboard_devices**](docs/apis/tags/DeviceApi.md#onboard_devices) | **post** /devices/:onboard | Onboard Devices
*DeviceApi* | [**override_device_level_ssid**](docs/apis/tags/DeviceApi.md#override_device_level_ssid) | **post** /devices/{id}/ssid/:override | Override SSID for a device
*DeviceApi* | [**query_devices_client_monitor**](docs/apis/tags/DeviceApi.md#query_devices_client_monitor) | **post** /devices/client-monitor/:query | Query client monitor setting for multiple devices
*DeviceApi* | [**query_devices_location**](docs/apis/tags/DeviceApi.md#query_devices_location) | **post** /devices/location/:query | Query location for multiple devices
*DeviceApi* | [**query_devices_network_policy**](docs/apis/tags/DeviceApi.md#query_devices_network_policy) | **post** /devices/network-policy/:query | Query network policy for multiple devices
*DeviceApi* | [**reboot_device**](docs/apis/tags/DeviceApi.md#reboot_device) | **post** /devices/{id}/:reboot | Reboot a device
*DeviceApi* | [**reboot_devices**](docs/apis/tags/DeviceApi.md#reboot_devices) | **post** /devices/:reboot | Reboot devices
*DeviceApi* | [**reset_device**](docs/apis/tags/DeviceApi.md#reset_device) | **post** /devices/{id}/:reset | [LRO] Reset a device to factory default
*DeviceApi* | [**revoke_device_client_monitor**](docs/apis/tags/DeviceApi.md#revoke_device_client_monitor) | **delete** /devices/{id}/client-monitor | Revoke client monitor setting for a device
*DeviceApi* | [**revoke_device_location**](docs/apis/tags/DeviceApi.md#revoke_device_location) | **delete** /devices/{id}/location | Revoke location for a device
*DeviceApi* | [**revoke_device_network_policy**](docs/apis/tags/DeviceApi.md#revoke_device_network_policy) | **delete** /devices/{id}/network-policy | Revoke network policy for a device
*DeviceApi* | [**revoke_devices_client_monitor**](docs/apis/tags/DeviceApi.md#revoke_devices_client_monitor) | **post** /devices/client-monitor/:revoke | Revoke client monitor setting for multiple devices
*DeviceApi* | [**revoke_devices_location**](docs/apis/tags/DeviceApi.md#revoke_devices_location) | **post** /devices/location/:revoke | Revoke location for multiple devices
*DeviceApi* | [**revoke_devices_network_policy**](docs/apis/tags/DeviceApi.md#revoke_devices_network_policy) | **post** /devices/network-policy/:revoke | Revoke network policy for multiple devices
*DeviceApi* | [**revoke_devices_radius_proxy**](docs/apis/tags/DeviceApi.md#revoke_devices_radius_proxy) | **delete** /devices/radius-proxy/:revoke | Revoke RADIUS proxy from multiple devices
*DeviceApi* | [**rm_device_list**](docs/apis/tags/DeviceApi.md#rm_device_list) | **post** /devices/rm-devices-page | RM Device Page
*DeviceApi* | [**send_cli_to_device**](docs/apis/tags/DeviceApi.md#send_cli_to_device) | **post** /devices/{id}/:cli | Send CLI to a device
*DeviceApi* | [**send_cli_to_devices**](docs/apis/tags/DeviceApi.md#send_cli_to_devices) | **post** /devices/:cli | [LRO] Send CLI to devices
*DeviceApi* | [**start_thread_commissioner**](docs/apis/tags/DeviceApi.md#start_thread_commissioner) | **post** /devices/{id}/thread/commissioner/:start | Start Thread Commissioner
*DeviceApi* | [**stop_thread_commissioner**](docs/apis/tags/DeviceApi.md#stop_thread_commissioner) | **post** /devices/{id}/thread/commissioner/:stop | Stop Thread Commissioner
*DeviceApi* | [**update_device_visible**](docs/apis/tags/DeviceApi.md#update_device_visible) | **put** /devices/{id}/visible | Update the visible status of a device in a floor
*EssentialsExtremeLocationApi* | [**get_client_last_location**](docs/apis/tags/EssentialsExtremeLocationApi.md#get_client_last_location) | **get** /essentials/eloc/clients/{clientMac}/last-known-location | Get the last known location of the client
*GeoViewApi* | [**get_geo_view_data**](docs/apis/tags/GeoViewApi.md#get_geo_view_data) | **get** /geo-view | Get GeoView Data
*HIQApi* | [**create_organization**](docs/apis/tags/HIQApi.md#create_organization) | **post** /hiq/organizations | Create a new organization
*HIQApi* | [**delete_organization**](docs/apis/tags/HIQApi.md#delete_organization) | **delete** /hiq/organizations/{id} | Delete an existing organization
*HIQApi* | [**get_creating_org_id**](docs/apis/tags/HIQApi.md#get_creating_org_id) | **get** /hiq/context/creating | Get organization for creating new data
*HIQApi* | [**get_hiq_context**](docs/apis/tags/HIQApi.md#get_hiq_context) | **get** /hiq/context | Get HIQ context
*HIQApi* | [**get_hiq_status**](docs/apis/tags/HIQApi.md#get_hiq_status) | **get** /hiq/status | Get HIQ status
*HIQApi* | [**get_reading_org_ids**](docs/apis/tags/HIQApi.md#get_reading_org_ids) | **get** /hiq/context/reading | Get organizations for reading data
*HIQApi* | [**list_organizations**](docs/apis/tags/HIQApi.md#list_organizations) | **get** /hiq/organizations | List all organizations
*HIQApi* | [**rename_organization**](docs/apis/tags/HIQApi.md#rename_organization) | **post** /hiq/organizations/{id}/:rename | Rename an existing organization
*HIQApi* | [**set_creating_org_id**](docs/apis/tags/HIQApi.md#set_creating_org_id) | **put** /hiq/context/creating | Set organization for creating new data
*HIQApi* | [**set_hiq_context**](docs/apis/tags/HIQApi.md#set_hiq_context) | **put** /hiq/context | Set HIQ context
*HIQApi* | [**set_reading_org_ids**](docs/apis/tags/HIQApi.md#set_reading_org_ids) | **put** /hiq/context/reading | Set organizations for reading data
*LocationApi* | [**create_building**](docs/apis/tags/LocationApi.md#create_building) | **post** /locations/building | Create a building
*LocationApi* | [**create_floor**](docs/apis/tags/LocationApi.md#create_floor) | **post** /locations/floor | Create a floor
*LocationApi* | [**create_location**](docs/apis/tags/LocationApi.md#create_location) | **post** /locations | Create a location
*LocationApi* | [**create_site**](docs/apis/tags/LocationApi.md#create_site) | **post** /locations/site | Create a site
*LocationApi* | [**delete_building**](docs/apis/tags/LocationApi.md#delete_building) | **delete** /locations/building/{id} | Delete a building by ID
*LocationApi* | [**delete_floor**](docs/apis/tags/LocationApi.md#delete_floor) | **delete** /locations/floor/{id} | Delete a floor by ID
*LocationApi* | [**delete_location**](docs/apis/tags/LocationApi.md#delete_location) | **delete** /locations/{id} | Delete a location by ID
*LocationApi* | [**delete_site**](docs/apis/tags/LocationApi.md#delete_site) | **delete** /locations/site/{id} | Delete a site by ID
*LocationApi* | [**get_building**](docs/apis/tags/LocationApi.md#get_building) | **get** /locations/building/{id} | Get a building by ID
*LocationApi* | [**get_floor**](docs/apis/tags/LocationApi.md#get_floor) | **get** /locations/floor/{id} | Get a floor by ID
*LocationApi* | [**get_location_devices_list**](docs/apis/tags/LocationApi.md#get_location_devices_list) | **get** /locations/tree/devices | Get devices on the location hierarchy.
*LocationApi* | [**get_location_maps_list**](docs/apis/tags/LocationApi.md#get_location_maps_list) | **get** /locations/tree/maps | Get maps on the location hierarchy.
*LocationApi* | [**get_location_tree**](docs/apis/tags/LocationApi.md#get_location_tree) | **get** /locations/tree | Get location tree
*LocationApi* | [**get_site**](docs/apis/tags/LocationApi.md#get_site) | **get** /locations/site/{id} | Get a site by ID
*LocationApi* | [**initialize_location**](docs/apis/tags/LocationApi.md#initialize_location) | **post** /locations/:init | Initialize organization location
*LocationApi* | [**list_buildings**](docs/apis/tags/LocationApi.md#list_buildings) | **get** /locations/building | List buildings
*LocationApi* | [**list_floors**](docs/apis/tags/LocationApi.md#list_floors) | **get** /locations/floor | List floors
*LocationApi* | [**list_sites**](docs/apis/tags/LocationApi.md#list_sites) | **get** /locations/site | List sites
*LocationApi* | [**start_ekahau_import**](docs/apis/tags/LocationApi.md#start_ekahau_import) | **post** /locations/import/ekahau | [LRO] Import one or more floors from an Ekahau archive
*LocationApi* | [**update_building**](docs/apis/tags/LocationApi.md#update_building) | **put** /locations/building/{id} | Update a building
*LocationApi* | [**update_floor**](docs/apis/tags/LocationApi.md#update_floor) | **put** /locations/floor/{id} | Update a floor
*LocationApi* | [**update_location**](docs/apis/tags/LocationApi.md#update_location) | **put** /locations/{id} | Update a location
*LocationApi* | [**update_site**](docs/apis/tags/LocationApi.md#update_site) | **put** /locations/site/{id} | Update a site by ID
*LocationApi* | [**upload_floorplan**](docs/apis/tags/LocationApi.md#upload_floorplan) | **post** /locations/floorplan | Upload floorplan
*LogApi* | [**audit_logs_report**](docs/apis/tags/LogApi.md#audit_logs_report) | **post** /logs/audit/reports | [LRO] Create audit logs report
*LogApi* | [**download_audit_logs_report**](docs/apis/tags/LogApi.md#download_audit_logs_report) | **get** /logs/audit/reports/{id} | Download audit logs
*LogApi* | [**get_audit_log_full_descriptions**](docs/apis/tags/LogApi.md#get_audit_log_full_descriptions) | **get** /logs/audit/full-descriptions/{id} | Get audit log full descriptions
*LogApi* | [**list_accounting_logs**](docs/apis/tags/LogApi.md#list_accounting_logs) | **get** /logs/accounting | List accounting logs
*LogApi* | [**list_audit_logs**](docs/apis/tags/LogApi.md#list_audit_logs) | **get** /logs/audit | List audit logs
*LogApi* | [**list_auth_logs**](docs/apis/tags/LogApi.md#list_auth_logs) | **get** /logs/auth | List auth logs
*LogApi* | [**list_credential_logs**](docs/apis/tags/LogApi.md#list_credential_logs) | **get** /logs/credential | List credential logs
*LogApi* | [**list_email_logs**](docs/apis/tags/LogApi.md#list_email_logs) | **get** /logs/email | List Email logs
*LogApi* | [**list_sms_logs**](docs/apis/tags/LogApi.md#list_sms_logs) | **get** /logs/sms | List SMS logs
*MiscApi* | [**get_country_list**](docs/apis/tags/MiscApi.md#get_country_list) | **get** /countries | Get country list
*MiscApi* | [**get_state_list_by_country_code**](docs/apis/tags/MiscApi.md#get_state_list_by_country_code) | **get** /countries/{countryAlpha2Code}/states | Get state list by country code
*MiscApi* | [**validate_country_code**](docs/apis/tags/MiscApi.md#validate_country_code) | **get** /countries/{countryCode}/:validate | Validate country code
*NOSApi* | [**get_device**](docs/apis/tags/NOSApi.md#get_device) | **post** /nos/device/{deviceId}/nos-api | Get device info for a specific device
*NetworkPolicyApi* | [**add_ssids_to_network_policy**](docs/apis/tags/NetworkPolicyApi.md#add_ssids_to_network_policy) | **post** /network-policies/{id}/ssids/:add | Add SSIDs to a network policy
*NetworkPolicyApi* | [**create_network_policy**](docs/apis/tags/NetworkPolicyApi.md#create_network_policy) | **post** /network-policies | Create network policy
*NetworkPolicyApi* | [**delete_network_policy**](docs/apis/tags/NetworkPolicyApi.md#delete_network_policy) | **delete** /network-policies/{id} | Delete the network policy
*NetworkPolicyApi* | [**delete_ssids_from_network_policy**](docs/apis/tags/NetworkPolicyApi.md#delete_ssids_from_network_policy) | **post** /network-policies/{id}/ssids/:remove | Removes SSIDs from the network policy
*NetworkPolicyApi* | [**get_network_policy**](docs/apis/tags/NetworkPolicyApi.md#get_network_policy) | **get** /network-policies/{id} | Get the network policy
*NetworkPolicyApi* | [**list_network_polices**](docs/apis/tags/NetworkPolicyApi.md#list_network_polices) | **get** /network-policies | List network policies
*NetworkPolicyApi* | [**list_ssids_by_network_policy**](docs/apis/tags/NetworkPolicyApi.md#list_ssids_by_network_policy) | **get** /network-policies/{id}/ssids | List SSIDs for a network policy
*NetworkPolicyApi* | [**update_network_policy**](docs/apis/tags/NetworkPolicyApi.md#update_network_policy) | **put** /network-policies/{id} | Update the network policy
*NetworkScorecardApi* | [**get_client_health**](docs/apis/tags/NetworkScorecardApi.md#get_client_health) | **get** /network-scorecard/clientHealth/{locationId} | Get the overall client health score
*NetworkScorecardApi* | [**get_device_health**](docs/apis/tags/NetworkScorecardApi.md#get_device_health) | **get** /network-scorecard/deviceHealth/{locationId} | Get the overall device health score
*NetworkScorecardApi* | [**get_network_health**](docs/apis/tags/NetworkScorecardApi.md#get_network_health) | **get** /network-scorecard/networkHealth/{locationId} | Get the overall network health score
*NetworkScorecardApi* | [**get_services_health**](docs/apis/tags/NetworkScorecardApi.md#get_services_health) | **get** /network-scorecard/servicesHealth/{locationId} | Get the overall services health score
*NetworkScorecardApi* | [**get_wifi_health**](docs/apis/tags/NetworkScorecardApi.md#get_wifi_health) | **get** /network-scorecard/wifiHealth/{locationId} | Get the overall wifi health score
*NotificationApi* | [**call_list**](docs/apis/tags/NotificationApi.md#call_list) | **get** /subscriptions/webhook | List webhook subscriptions
*NotificationApi* | [**create_subscriptions**](docs/apis/tags/NotificationApi.md#create_subscriptions) | **post** /subscriptions/webhook | Create webhook subscriptions
*NotificationApi* | [**delete_subscription**](docs/apis/tags/NotificationApi.md#delete_subscription) | **delete** /subscriptions/webhook/:delete | Delete webhook subscription
*NotificationApi* | [**export_to_csv4**](docs/apis/tags/NotificationApi.md#export_to_csv4) | **get** /subscriptions/webhook/export | Export all webhook subscriptions to CSV
*NotificationApi* | [**update_webhook_subscription**](docs/apis/tags/NotificationApi.md#update_webhook_subscription) | **put** /subscriptions/webhook/{id} | Update webhook subscription
*OperationApi* | [**cancel_operation**](docs/apis/tags/OperationApi.md#cancel_operation) | **post** /operations/{operationId}/:cancel | Cancel Long-Running Operation (LRO)
*OperationApi* | [**delete_operation**](docs/apis/tags/OperationApi.md#delete_operation) | **delete** /operations/{operationId} | Delete Long-Running Operation (LRO)
*OperationApi* | [**get_operation**](docs/apis/tags/OperationApi.md#get_operation) | **get** /operations/{operationId} | Get Long-Running Operation (LRO) status and result
*PacketCaptureApi* | [**create_packet_capture**](docs/apis/tags/PacketCaptureApi.md#create_packet_capture) | **post** /packetcaptures | Create a new packet capture session
*PacketCaptureApi* | [**delete_packet_capture**](docs/apis/tags/PacketCaptureApi.md#delete_packet_capture) | **delete** /packetcaptures/{id} | Delete a packet capture session
*PacketCaptureApi* | [**get_packet_capture**](docs/apis/tags/PacketCaptureApi.md#get_packet_capture) | **get** /packetcaptures/{id} | Get a packet capture session
*PacketCaptureApi* | [**get_packet_capture_file**](docs/apis/tags/PacketCaptureApi.md#get_packet_capture_file) | **get** /packetcaptures/files | Get an AP packet capture file
*PacketCaptureApi* | [**list_packet_captures**](docs/apis/tags/PacketCaptureApi.md#list_packet_captures) | **get** /packetcaptures | List packet capture sessions
*PacketCaptureApi* | [**stop_packet_capture**](docs/apis/tags/PacketCaptureApi.md#stop_packet_capture) | **post** /packetcaptures/{id}/:stop | Stop a packet capture session
*PacketCaptureApi* | [**upload_packet_capture_files**](docs/apis/tags/PacketCaptureApi.md#upload_packet_capture_files) | **post** /packetcaptures/{id}/:upload | Upload a packet capture session&#x27;s capture files
*ThreadApi* | [**get_thread_network_topology**](docs/apis/tags/ThreadApi.md#get_thread_network_topology) | **get** /thread/topology | Get thread network topology
*ThreadApi* | [**get_thread_networks**](docs/apis/tags/ThreadApi.md#get_thread_networks) | **get** /thread/networks | Get active thread networks
*ThreadApi* | [**get_thread_routers**](docs/apis/tags/ThreadApi.md#get_thread_routers) | **get** /thread/routers | List thread routers
*UniversalComputePlatformApi* | [**get_ucp_engines**](docs/apis/tags/UniversalComputePlatformApi.md#get_ucp_engines) | **get** /ucp/{id}/engines/installed | Get UCP Engines by ID
*UserApi* | [**create_user**](docs/apis/tags/UserApi.md#create_user) | **post** /users | Create new user
*UserApi* | [**delete_user**](docs/apis/tags/UserApi.md#delete_user) | **delete** /users/{id} | Delete user by ID
*UserApi* | [**get_current_user**](docs/apis/tags/UserApi.md#get_current_user) | **get** /users/me | Get current user info
*UserApi* | [**get_external_user**](docs/apis/tags/UserApi.md#get_external_user) | **get** /users/external/{id} | Get external access info
*UserApi* | [**get_user**](docs/apis/tags/UserApi.md#get_user) | **get** /users/{id} | Get user info by ID
*UserApi* | [**grant_external_user**](docs/apis/tags/UserApi.md#grant_external_user) | **post** /users/external | Grant external access
*UserApi* | [**list_external_users**](docs/apis/tags/UserApi.md#list_external_users) | **get** /users/external | List external access users
*UserApi* | [**list_users**](docs/apis/tags/UserApi.md#list_users) | **get** /users | List all users
*UserApi* | [**revoke_external_user**](docs/apis/tags/UserApi.md#revoke_external_user) | **delete** /users/external/{id} | Revoke external access
*UserApi* | [**update_external_user**](docs/apis/tags/UserApi.md#update_external_user) | **patch** /users/external/{id} | Update external access info
*UserApi* | [**update_user**](docs/apis/tags/UserApi.md#update_user) | **patch** /users/{id} | Update user info
*AfcEndpointApi* | [**create_site_afc_schedule**](docs/apis/tags/AfcEndpointApi.md#create_site_afc_schedule) | **post** /site/afc/schedule | 
*AfcEndpointApi* | [**get_afc_server**](docs/apis/tags/AfcEndpointApi.md#get_afc_server) | **get** /afcserver/{server_id} | Get Afc Server data
*AfcEndpointApi* | [**get_afc_server_statistics**](docs/apis/tags/AfcEndpointApi.md#get_afc_server_statistics) | **get** /afcserver/statistics/{server_id} | Get AFC server Statistics
*AfcEndpointApi* | [**get_afc_spectrum_per_ap**](docs/apis/tags/AfcEndpointApi.md#get_afc_spectrum_per_ap) | **post** /ap/spectrum/ | 
*AfcEndpointApi* | [**get_afc_spectrum_per_site**](docs/apis/tags/AfcEndpointApi.md#get_afc_spectrum_per_site) | **post** /site/spectrum/ | 
*AfcEndpointApi* | [**get_aps_afc_diagnostics**](docs/apis/tags/AfcEndpointApi.md#get_aps_afc_diagnostics) | **get** /ap/afc/diagnostics/{id} | 
*AfcEndpointApi* | [**get_aps_afc_info**](docs/apis/tags/AfcEndpointApi.md#get_aps_afc_info) | **get** /ap/afc/interface/details/{sn} | Get Afc Summary Data
*AfcEndpointApi* | [**get_aps_afc_summary_info**](docs/apis/tags/AfcEndpointApi.md#get_aps_afc_summary_info) | **get** /aps/afc/query/ | 
*AfcEndpointApi* | [**get_site_afc_schedule**](docs/apis/tags/AfcEndpointApi.md#get_site_afc_schedule) | **get** /site/afc/schedule | 
*AfcEndpointApi* | [**list_afc_servers**](docs/apis/tags/AfcEndpointApi.md#list_afc_servers) | **get** /afcserver | Get Afc Server list and their status
*AfcEndpointApi* | [**post_aps_manual_afc_spectrum**](docs/apis/tags/AfcEndpointApi.md#post_aps_manual_afc_spectrum) | **post** /aps/afc/update | Manual Spectrum request for device(s)
*AfcEndpointApi* | [**update_site_afc_schedule**](docs/apis/tags/AfcEndpointApi.md#update_site_afc_schedule) | **put** /site/afc/schedule | 
*RttsEndpointApi* | [**create_rtts_session**](docs/apis/tags/RttsEndpointApi.md#create_rtts_session) | **post** /rtts | Create
*RttsEndpointApi* | [**delete_rtts_session**](docs/apis/tags/RttsEndpointApi.md#delete_rtts_session) | **delete** /rtts/{id} | 

## Documentation For Models

 - [ClientHealth](docs/models/ClientHealth.md)
 - [DeviceHealth](docs/models/DeviceHealth.md)
 - [EssentialsElocLastKnownLocation](docs/models/EssentialsElocLastKnownLocation.md)
 - [GeoViewNode](docs/models/GeoViewNode.md)
 - [NetworkHealth](docs/models/NetworkHealth.md)
 - [PagedXiqAccountingLog](docs/models/PagedXiqAccountingLog.md)
 - [PagedXiqActiveDirectoryServer](docs/models/PagedXiqActiveDirectoryServer.md)
 - [PagedXiqAlert](docs/models/PagedXiqAlert.md)
 - [PagedXiqApiAccessToken](docs/models/PagedXiqApiAccessToken.md)
 - [PagedXiqApplication](docs/models/PagedXiqApplication.md)
 - [PagedXiqAuditLog](docs/models/PagedXiqAuditLog.md)
 - [PagedXiqAuthLog](docs/models/PagedXiqAuthLog.md)
 - [PagedXiqBackupHistory](docs/models/PagedXiqBackupHistory.md)
 - [PagedXiqBuilding](docs/models/PagedXiqBuilding.md)
 - [PagedXiqCertificate](docs/models/PagedXiqCertificate.md)
 - [PagedXiqClassificationRule](docs/models/PagedXiqClassificationRule.md)
 - [PagedXiqClient](docs/models/PagedXiqClient.md)
 - [PagedXiqClientHealthGridResponse](docs/models/PagedXiqClientHealthGridResponse.md)
 - [PagedXiqClientMonitorProfile](docs/models/PagedXiqClientMonitorProfile.md)
 - [PagedXiqClientStatsGridRow](docs/models/PagedXiqClientStatsGridRow.md)
 - [PagedXiqCloudConfigGroup](docs/models/PagedXiqCloudConfigGroup.md)
 - [PagedXiqConnectivityExperienceData](docs/models/PagedXiqConnectivityExperienceData.md)
 - [PagedXiqCopilotWirelessEvent](docs/models/PagedXiqCopilotWirelessEvent.md)
 - [PagedXiqCredentialDistributionGroupUpdate](docs/models/PagedXiqCredentialDistributionGroupUpdate.md)
 - [PagedXiqCredentialLog](docs/models/PagedXiqCredentialLog.md)
 - [PagedXiqCwp](docs/models/PagedXiqCwp.md)
 - [PagedXiqDeploymentDetailsResponse](docs/models/PagedXiqDeploymentDetailsResponse.md)
 - [PagedXiqDevice](docs/models/PagedXiqDevice.md)
 - [PagedXiqDeviceAlarm](docs/models/PagedXiqDeviceAlarm.md)
 - [PagedXiqDeviceHealthGridResponse](docs/models/PagedXiqDeviceHealthGridResponse.md)
 - [PagedXiqDeviceRebootSummary](docs/models/PagedXiqDeviceRebootSummary.md)
 - [PagedXiqDigitalTwinProducts](docs/models/PagedXiqDigitalTwinProducts.md)
 - [PagedXiqEmailLog](docs/models/PagedXiqEmailLog.md)
 - [PagedXiqEndUser](docs/models/PagedXiqEndUser.md)
 - [PagedXiqExternalRadiusServer](docs/models/PagedXiqExternalRadiusServer.md)
 - [PagedXiqExternalUser](docs/models/PagedXiqExternalUser.md)
 - [PagedXiqFloor](docs/models/PagedXiqFloor.md)
 - [PagedXiqHotspotProfile](docs/models/PagedXiqHotspotProfile.md)
 - [PagedXiqHotspotServiceProviderProfile](docs/models/PagedXiqHotspotServiceProviderProfile.md)
 - [PagedXiqInternalRadiusDevice](docs/models/PagedXiqInternalRadiusDevice.md)
 - [PagedXiqInternalRadiusServer](docs/models/PagedXiqInternalRadiusServer.md)
 - [PagedXiqIotProfile](docs/models/PagedXiqIotProfile.md)
 - [PagedXiqIpFirewall](docs/models/PagedXiqIpFirewall.md)
 - [PagedXiqLdapServer](docs/models/PagedXiqLdapServer.md)
 - [PagedXiqLocationTreeDevice](docs/models/PagedXiqLocationTreeDevice.md)
 - [PagedXiqLocationTreeMap](docs/models/PagedXiqLocationTreeMap.md)
 - [PagedXiqMacFirewall](docs/models/PagedXiqMacFirewall.md)
 - [PagedXiqMacObject](docs/models/PagedXiqMacObject.md)
 - [PagedXiqNetworkPolicy](docs/models/PagedXiqNetworkPolicy.md)
 - [PagedXiqNetworkService](docs/models/PagedXiqNetworkService.md)
 - [PagedXiqPacketCapture](docs/models/PagedXiqPacketCapture.md)
 - [PagedXiqRadioEntity](docs/models/PagedXiqRadioEntity.md)
 - [PagedXiqRadioProfile](docs/models/PagedXiqRadioProfile.md)
 - [PagedXiqRadiusClientObject](docs/models/PagedXiqRadiusClientObject.md)
 - [PagedXiqRadiusProxy](docs/models/PagedXiqRadiusProxy.md)
 - [PagedXiqRmDevice](docs/models/PagedXiqRmDevice.md)
 - [PagedXiqRpMacOuiProfile](docs/models/PagedXiqRpMacOuiProfile.md)
 - [PagedXiqSite](docs/models/PagedXiqSite.md)
 - [PagedXiqSiteDashboardResponse](docs/models/PagedXiqSiteDashboardResponse.md)
 - [PagedXiqSmsLog](docs/models/PagedXiqSmsLog.md)
 - [PagedXiqSsid](docs/models/PagedXiqSsid.md)
 - [PagedXiqSurroundingAps](docs/models/PagedXiqSurroundingAps.md)
 - [PagedXiqThreadRouter](docs/models/PagedXiqThreadRouter.md)
 - [PagedXiqTunnelConcentrator](docs/models/PagedXiqTunnelConcentrator.md)
 - [PagedXiqUsageCapacityGridResponse](docs/models/PagedXiqUsageCapacityGridResponse.md)
 - [PagedXiqUser](docs/models/PagedXiqUser.md)
 - [PagedXiqUserGroup](docs/models/PagedXiqUserGroup.md)
 - [PagedXiqUserProfile](docs/models/PagedXiqUserProfile.md)
 - [PagedXiqUserProfileAssignment](docs/models/PagedXiqUserProfileAssignment.md)
 - [PagedXiqVlanProfile](docs/models/PagedXiqVlanProfile.md)
 - [PagedXiqWebhookSubscription](docs/models/PagedXiqWebhookSubscription.md)
 - [PagedXiqWiredEventEntity](docs/models/PagedXiqWiredEventEntity.md)
 - [RttsSessionDevices](docs/models/RttsSessionDevices.md)
 - [ServicesHealth](docs/models/ServicesHealth.md)
 - [WifiHealth](docs/models/WifiHealth.md)
 - [XiqAccount](docs/models/XiqAccount.md)
 - [XiqAccountMode](docs/models/XiqAccountMode.md)
 - [XiqAccountType](docs/models/XiqAccountType.md)
 - [XiqAccountingLog](docs/models/XiqAccountingLog.md)
 - [XiqAcknowledgeAlertsRequest](docs/models/XiqAcknowledgeAlertsRequest.md)
 - [XiqActionType](docs/models/XiqActionType.md)
 - [XiqActiveDirectoryServer](docs/models/XiqActiveDirectoryServer.md)
 - [XiqActiveDirectoryServerBaseDnFetchMode](docs/models/XiqActiveDirectoryServerBaseDnFetchMode.md)
 - [XiqAddress](docs/models/XiqAddress.md)
 - [XiqAddressProfileClassifiedEntry](docs/models/XiqAddressProfileClassifiedEntry.md)
 - [XiqAdvancedOnboardDeviceRequest](docs/models/XiqAdvancedOnboardDeviceRequest.md)
 - [XiqAdvancedOnboardDeviceResponse](docs/models/XiqAdvancedOnboardDeviceResponse.md)
 - [XiqAfcApDetail](docs/models/XiqAfcApDetail.md)
 - [XiqAfcApDiagnostics](docs/models/XiqAfcApDiagnostics.md)
 - [XiqAfcApManualSpectrum](docs/models/XiqAfcApManualSpectrum.md)
 - [XiqAfcApsInfoElement](docs/models/XiqAfcApsInfoElement.md)
 - [XiqAfcAvailableSpectrum](docs/models/XiqAfcAvailableSpectrum.md)
 - [XiqAfcGeolocationSummary](docs/models/XiqAfcGeolocationSummary.md)
 - [XiqAfcInputInfo](docs/models/XiqAfcInputInfo.md)
 - [XiqAfcServer](docs/models/XiqAfcServer.md)
 - [XiqAfcServerState](docs/models/XiqAfcServerState.md)
 - [XiqAfcServerStatistics](docs/models/XiqAfcServerStatistics.md)
 - [XiqAfcServersStatistics](docs/models/XiqAfcServersStatistics.md)
 - [XiqAfcStatusSummary](docs/models/XiqAfcStatusSummary.md)
 - [XiqAffectedDownlinkDevice](docs/models/XiqAffectedDownlinkDevice.md)
 - [XiqAlert](docs/models/XiqAlert.md)
 - [XiqAlertDashboard](docs/models/XiqAlertDashboard.md)
 - [XiqAlertEmailSubscription](docs/models/XiqAlertEmailSubscription.md)
 - [XiqAlertEventRulesByCategory](docs/models/XiqAlertEventRulesByCategory.md)
 - [XiqAlertGroupCount](docs/models/XiqAlertGroupCount.md)
 - [XiqAlertGroupQuery](docs/models/XiqAlertGroupQuery.md)
 - [XiqAlertMetricRulesByMetricset](docs/models/XiqAlertMetricRulesByMetricset.md)
 - [XiqAlertPolicy](docs/models/XiqAlertPolicy.md)
 - [XiqAlertPolicyFilter](docs/models/XiqAlertPolicyFilter.md)
 - [XiqAlertPolicyType](docs/models/XiqAlertPolicyType.md)
 - [XiqAlertReport](docs/models/XiqAlertReport.md)
 - [XiqAlertRule](docs/models/XiqAlertRule.md)
 - [XiqAlertRuleOverview](docs/models/XiqAlertRuleOverview.md)
 - [XiqAlertServiceNowSubscription](docs/models/XiqAlertServiceNowSubscription.md)
 - [XiqAlertSite](docs/models/XiqAlertSite.md)
 - [XiqAlertSortField](docs/models/XiqAlertSortField.md)
 - [XiqAlertSource](docs/models/XiqAlertSource.md)
 - [XiqAlertTag](docs/models/XiqAlertTag.md)
 - [XiqAlertWebhookSubscription](docs/models/XiqAlertWebhookSubscription.md)
 - [XiqAnomaliesCountVoEntity](docs/models/XiqAnomaliesCountVoEntity.md)
 - [XiqAnomaliesDeviceUpdateActionRequest](docs/models/XiqAnomaliesDeviceUpdateActionRequest.md)
 - [XiqAnomaliesFeedbackRequest](docs/models/XiqAnomaliesFeedbackRequest.md)
 - [XiqAnomaliesNotificationsResponse](docs/models/XiqAnomaliesNotificationsResponse.md)
 - [XiqAnomaliesSeverityEntity](docs/models/XiqAnomaliesSeverityEntity.md)
 - [XiqAnomaliesSiteEntity](docs/models/XiqAnomaliesSiteEntity.md)
 - [XiqAnomaliesTypeEntity](docs/models/XiqAnomaliesTypeEntity.md)
 - [XiqAnomaliesUpdateActionRequest](docs/models/XiqAnomaliesUpdateActionRequest.md)
 - [XiqAnomalyAffectedCount](docs/models/XiqAnomalyAffectedCount.md)
 - [XiqAnomalyDeviceEntity](docs/models/XiqAnomalyDeviceEntity.md)
 - [XiqAnomalyDeviceWithLocation](docs/models/XiqAnomalyDeviceWithLocation.md)
 - [XiqAnomalyDevicesByLocationResponse](docs/models/XiqAnomalyDevicesByLocationResponse.md)
 - [XiqAnomalyHealthType](docs/models/XiqAnomalyHealthType.md)
 - [XiqAnomalyHhStatsType](docs/models/XiqAnomalyHhStatsType.md)
 - [XiqAnomalyLocationEntity](docs/models/XiqAnomalyLocationEntity.md)
 - [XiqAnomalySeverity](docs/models/XiqAnomalySeverity.md)
 - [XiqAnomalySortField](docs/models/XiqAnomalySortField.md)
 - [XiqAnomalyType](docs/models/XiqAnomalyType.md)
 - [XiqApCoordinates](docs/models/XiqApCoordinates.md)
 - [XiqApiAccessToken](docs/models/XiqApiAccessToken.md)
 - [XiqApiAccessTokenSortField](docs/models/XiqApiAccessTokenSortField.md)
 - [XiqApiTokenInfo](docs/models/XiqApiTokenInfo.md)
 - [XiqApplication](docs/models/XiqApplication.md)
 - [XiqApplicationDetectionProtocol](docs/models/XiqApplicationDetectionProtocol.md)
 - [XiqApplicationDetectionRule](docs/models/XiqApplicationDetectionRule.md)
 - [XiqApplicationDetectionType](docs/models/XiqApplicationDetectionType.md)
 - [XiqApplicationService](docs/models/XiqApplicationService.md)
 - [XiqApplicationSortField](docs/models/XiqApplicationSortField.md)
 - [XiqApplicationTopClientsUsage](docs/models/XiqApplicationTopClientsUsage.md)
 - [XiqAssetDashboard](docs/models/XiqAssetDashboard.md)
 - [XiqAssignDevicesClientMonitorRequest](docs/models/XiqAssignDevicesClientMonitorRequest.md)
 - [XiqAssignDevicesCountryCodeRequest](docs/models/XiqAssignDevicesCountryCodeRequest.md)
 - [XiqAssignDevicesLocationRequest](docs/models/XiqAssignDevicesLocationRequest.md)
 - [XiqAssignDevicesNetworkPolicyRequest](docs/models/XiqAssignDevicesNetworkPolicyRequest.md)
 - [XiqAssuranceScansOverviewResponse](docs/models/XiqAssuranceScansOverviewResponse.md)
 - [XiqAtpDeviceStatsEntity](docs/models/XiqAtpDeviceStatsEntity.md)
 - [XiqAtpDeviceStatsResponse](docs/models/XiqAtpDeviceStatsResponse.md)
 - [XiqAtpPacketCountsEntity](docs/models/XiqAtpPacketCountsEntity.md)
 - [XiqAtpPacketCountsResponse](docs/models/XiqAtpPacketCountsResponse.md)
 - [XiqAttachClientMonitorProfileRequest](docs/models/XiqAttachClientMonitorProfileRequest.md)
 - [XiqAttachIpFirewallPolicyToUserProfileRequest](docs/models/XiqAttachIpFirewallPolicyToUserProfileRequest.md)
 - [XiqAttachMacFirewallPolicyToUserProfileRequest](docs/models/XiqAttachMacFirewallPolicyToUserProfileRequest.md)
 - [XiqAttachUPAssignmentEntry](docs/models/XiqAttachUPAssignmentEntry.md)
 - [XiqAttachUPAssignmentRequest](docs/models/XiqAttachUPAssignmentRequest.md)
 - [XiqAttributeType](docs/models/XiqAttributeType.md)
 - [XiqAuditLog](docs/models/XiqAuditLog.md)
 - [XiqAuditLogCategory](docs/models/XiqAuditLogCategory.md)
 - [XiqAuditLogFullDescriptions](docs/models/XiqAuditLogFullDescriptions.md)
 - [XiqAuditLogReport](docs/models/XiqAuditLogReport.md)
 - [XiqAuditLogSortField](docs/models/XiqAuditLogSortField.md)
 - [XiqAuthLog](docs/models/XiqAuthLog.md)
 - [XiqAvailableChannelInfo](docs/models/XiqAvailableChannelInfo.md)
 - [XiqBackupHistory](docs/models/XiqBackupHistory.md)
 - [XiqBounceDevicePortData](docs/models/XiqBounceDevicePortData.md)
 - [XiqBounceDevicePortOperationResult](docs/models/XiqBounceDevicePortOperationResult.md)
 - [XiqBounceDevicePortRequest](docs/models/XiqBounceDevicePortRequest.md)
 - [XiqBounceDevicePortResponse](docs/models/XiqBounceDevicePortResponse.md)
 - [XiqBuilding](docs/models/XiqBuilding.md)
 - [XiqBulkDeleteEmailSubscriptionResult](docs/models/XiqBulkDeleteEmailSubscriptionResult.md)
 - [XiqBulkDeleteServiceNowSubscriptionResult](docs/models/XiqBulkDeleteServiceNowSubscriptionResult.md)
 - [XiqBulkDeleteWebhookSubscriptionResult](docs/models/XiqBulkDeleteWebhookSubscriptionResult.md)
 - [XiqBulkOperationResult](docs/models/XiqBulkOperationResult.md)
 - [XiqCaptureBandSelection](docs/models/XiqCaptureBandSelection.md)
 - [XiqCaptureDirectionSelection](docs/models/XiqCaptureDirectionSelection.md)
 - [XiqCaptureFilter](docs/models/XiqCaptureFilter.md)
 - [XiqCaptureIdentifierType](docs/models/XiqCaptureIdentifierType.md)
 - [XiqCaptureLocation](docs/models/XiqCaptureLocation.md)
 - [XiqCaptureRadioSelection](docs/models/XiqCaptureRadioSelection.md)
 - [XiqCaptureResult](docs/models/XiqCaptureResult.md)
 - [XiqCaptureStopRequest](docs/models/XiqCaptureStopRequest.md)
 - [XiqCaptureWiredSelection](docs/models/XiqCaptureWiredSelection.md)
 - [XiqCdgUserGroups](docs/models/XiqCdgUserGroups.md)
 - [XiqCertificate](docs/models/XiqCertificate.md)
 - [XiqCertificateType](docs/models/XiqCertificateType.md)
 - [XiqChangeDevicesIbeaconRequest](docs/models/XiqChangeDevicesIbeaconRequest.md)
 - [XiqChangeDevicesOsModeRequest](docs/models/XiqChangeDevicesOsModeRequest.md)
 - [XiqChannelUtilizationDetails](docs/models/XiqChannelUtilizationDetails.md)
 - [XiqCheckPermissionRequest](docs/models/XiqCheckPermissionRequest.md)
 - [XiqCheckPermissionResponse](docs/models/XiqCheckPermissionResponse.md)
 - [XiqClassification](docs/models/XiqClassification.md)
 - [XiqClassificationRule](docs/models/XiqClassificationRule.md)
 - [XiqClassificationType](docs/models/XiqClassificationType.md)
 - [XiqCliOutput](docs/models/XiqCliOutput.md)
 - [XiqCliResponseCode](docs/models/XiqCliResponseCode.md)
 - [XiqClient](docs/models/XiqClient.md)
 - [XiqClientChartData](docs/models/XiqClientChartData.md)
 - [XiqClientChartDataList](docs/models/XiqClientChartDataList.md)
 - [XiqClientConnectionStatus](docs/models/XiqClientConnectionStatus.md)
 - [XiqClientDetail](docs/models/XiqClientDetail.md)
 - [XiqClientField](docs/models/XiqClientField.md)
 - [XiqClientGraphData](docs/models/XiqClientGraphData.md)
 - [XiqClientGridFilter](docs/models/XiqClientGridFilter.md)
 - [XiqClientHealthConnectivityIssues](docs/models/XiqClientHealthConnectivityIssues.md)
 - [XiqClientHealthDashboard](docs/models/XiqClientHealthDashboard.md)
 - [XiqClientHealthFrequencyDistribution](docs/models/XiqClientHealthFrequencyDistribution.md)
 - [XiqClientHealthGridResponse](docs/models/XiqClientHealthGridResponse.md)
 - [XiqClientHealthRoamingIssues](docs/models/XiqClientHealthRoamingIssues.md)
 - [XiqClientHealthSortField](docs/models/XiqClientHealthSortField.md)
 - [XiqClientMacAddressAlias](docs/models/XiqClientMacAddressAlias.md)
 - [XiqClientMonitorParameters](docs/models/XiqClientMonitorParameters.md)
 - [XiqClientMonitorProfile](docs/models/XiqClientMonitorProfile.md)
 - [XiqClientMonitorProfileRequest](docs/models/XiqClientMonitorProfileRequest.md)
 - [XiqClientSortField](docs/models/XiqClientSortField.md)
 - [XiqClientStats](docs/models/XiqClientStats.md)
 - [XiqClientStatsEntity](docs/models/XiqClientStatsEntity.md)
 - [XiqClientStatsGridRow](docs/models/XiqClientStatsGridRow.md)
 - [XiqClientSummary](docs/models/XiqClientSummary.md)
 - [XiqClientType](docs/models/XiqClientType.md)
 - [XiqClientUsage](docs/models/XiqClientUsage.md)
 - [XiqClientView](docs/models/XiqClientView.md)
 - [XiqCloudConfigGroup](docs/models/XiqCloudConfigGroup.md)
 - [XiqCloudConfigGroupSortField](docs/models/XiqCloudConfigGroupSortField.md)
 - [XiqCloudSharkStorage](docs/models/XiqCloudSharkStorage.md)
 - [XiqConnectivityDetailsByClientTypeResponse](docs/models/XiqConnectivityDetailsByClientTypeResponse.md)
 - [XiqConnectivityExperienceData](docs/models/XiqConnectivityExperienceData.md)
 - [XiqConnectivityExperienceViewType](docs/models/XiqConnectivityExperienceViewType.md)
 - [XiqCopilotAnomaliesActionResponse](docs/models/XiqCopilotAnomaliesActionResponse.md)
 - [XiqCopilotAnomaliesByCategory](docs/models/XiqCopilotAnomaliesByCategory.md)
 - [XiqCopilotEventsWiredSortField](docs/models/XiqCopilotEventsWiredSortField.md)
 - [XiqCopilotEventsWirelessSortField](docs/models/XiqCopilotEventsWirelessSortField.md)
 - [XiqCopilotLldpCdpInfo](docs/models/XiqCopilotLldpCdpInfo.md)
 - [XiqCopilotMissingVlanPagedXiqMissingVlanExcludedVlanList](docs/models/XiqCopilotMissingVlanPagedXiqMissingVlanExcludedVlanList.md)
 - [XiqCopilotMissingVlanSiteDetails](docs/models/XiqCopilotMissingVlanSiteDetails.md)
 - [XiqCopilotPagedXiqAnomalyDeviceWithLocation](docs/models/XiqCopilotPagedXiqAnomalyDeviceWithLocation.md)
 - [XiqCopilotPagedXiqAnomalyLocationEntity](docs/models/XiqCopilotPagedXiqAnomalyLocationEntity.md)
 - [XiqCopilotWiredEventsScoreType](docs/models/XiqCopilotWiredEventsScoreType.md)
 - [XiqCopilotWirelessEvent](docs/models/XiqCopilotWirelessEvent.md)
 - [XiqCopilotWirelessEventsScoreType](docs/models/XiqCopilotWirelessEventsScoreType.md)
 - [XiqCountApWithExcessiveRetriesResponse](docs/models/XiqCountApWithExcessiveRetriesResponse.md)
 - [XiqCountApWithPacketLossExcessiveResponse](docs/models/XiqCountApWithPacketLossExcessiveResponse.md)
 - [XiqCountry](docs/models/XiqCountry.md)
 - [XiqCountryCode](docs/models/XiqCountryCode.md)
 - [XiqCountryState](docs/models/XiqCountryState.md)
 - [XiqCreateAlertEmailSubscriptionRequest](docs/models/XiqCreateAlertEmailSubscriptionRequest.md)
 - [XiqCreateAlertServiceNowSubscriptionRequest](docs/models/XiqCreateAlertServiceNowSubscriptionRequest.md)
 - [XiqCreateAlertWebhookSubscriptionRequest](docs/models/XiqCreateAlertWebhookSubscriptionRequest.md)
 - [XiqCreateApiAccessTokenResponse](docs/models/XiqCreateApiAccessTokenResponse.md)
 - [XiqCreateBuildingRequest](docs/models/XiqCreateBuildingRequest.md)
 - [XiqCreateClassificationRequest](docs/models/XiqCreateClassificationRequest.md)
 - [XiqCreateClassificationRuleRequest](docs/models/XiqCreateClassificationRuleRequest.md)
 - [XiqCreateCloudConfigGroupRequest](docs/models/XiqCreateCloudConfigGroupRequest.md)
 - [XiqCreateEndUserRequest](docs/models/XiqCreateEndUserRequest.md)
 - [XiqCreateExternalRadiusServerRequest](docs/models/XiqCreateExternalRadiusServerRequest.md)
 - [XiqCreateFloorRequest](docs/models/XiqCreateFloorRequest.md)
 - [XiqCreateInternalRadiusServerRequest](docs/models/XiqCreateInternalRadiusServerRequest.md)
 - [XiqCreateKeyBasedPcgUsersRequest](docs/models/XiqCreateKeyBasedPcgUsersRequest.md)
 - [XiqCreateKeyBasedPcgUsersResponse](docs/models/XiqCreateKeyBasedPcgUsersResponse.md)
 - [XiqCreateL3AddressProfileRequest](docs/models/XiqCreateL3AddressProfileRequest.md)
 - [XiqCreateLdapServerRequest](docs/models/XiqCreateLdapServerRequest.md)
 - [XiqCreateLocationRequest](docs/models/XiqCreateLocationRequest.md)
 - [XiqCreateMacObjectRequest](docs/models/XiqCreateMacObjectRequest.md)
 - [XiqCreateNetworkPolicyRequest](docs/models/XiqCreateNetworkPolicyRequest.md)
 - [XiqCreateOrganizationRequest](docs/models/XiqCreateOrganizationRequest.md)
 - [XiqCreateRadioProfileRequest](docs/models/XiqCreateRadioProfileRequest.md)
 - [XiqCreateRadiusClient](docs/models/XiqCreateRadiusClient.md)
 - [XiqCreateRadiusClientObjectRequest](docs/models/XiqCreateRadiusClientObjectRequest.md)
 - [XiqCreateRadiusProxyRealm](docs/models/XiqCreateRadiusProxyRealm.md)
 - [XiqCreateRadiusProxyRequest](docs/models/XiqCreateRadiusProxyRequest.md)
 - [XiqCreateRpMacOuiProfileRequest](docs/models/XiqCreateRpMacOuiProfileRequest.md)
 - [XiqCreateSiteRequest](docs/models/XiqCreateSiteRequest.md)
 - [XiqCreateUserGroupRequest](docs/models/XiqCreateUserGroupRequest.md)
 - [XiqCreateUserProfileAssignmentRequest](docs/models/XiqCreateUserProfileAssignmentRequest.md)
 - [XiqCreateUserProfileRequest](docs/models/XiqCreateUserProfileRequest.md)
 - [XiqCreateUserRequest](docs/models/XiqCreateUserRequest.md)
 - [XiqCreateVlanObjectClassifiedEntryRequest](docs/models/XiqCreateVlanObjectClassifiedEntryRequest.md)
 - [XiqCreateVlanProfileRequest](docs/models/XiqCreateVlanProfileRequest.md)
 - [XiqCreateWebhookSubscriptionRequest](docs/models/XiqCreateWebhookSubscriptionRequest.md)
 - [XiqCreateWirelessClientHealthCriteria](docs/models/XiqCreateWirelessClientHealthCriteria.md)
 - [XiqCreateWirelessDashboardCriteriaParamRequest](docs/models/XiqCreateWirelessDashboardCriteriaParamRequest.md)
 - [XiqCreateWirelessDashboardCriteriaParamResponse](docs/models/XiqCreateWirelessDashboardCriteriaParamResponse.md)
 - [XiqCreateWirelessDeviceHealthCriteria](docs/models/XiqCreateWirelessDeviceHealthCriteria.md)
 - [XiqCreateWirelessUsageCapacityCriteria](docs/models/XiqCreateWirelessUsageCapacityCriteria.md)
 - [XiqCredentialDistributionGroup](docs/models/XiqCredentialDistributionGroup.md)
 - [XiqCredentialDistributionGroupCreateRequest](docs/models/XiqCredentialDistributionGroupCreateRequest.md)
 - [XiqCredentialDistributionGroupUpdate](docs/models/XiqCredentialDistributionGroupUpdate.md)
 - [XiqCredentialDistributionGroupUpdateRequest](docs/models/XiqCredentialDistributionGroupUpdateRequest.md)
 - [XiqCredentialLog](docs/models/XiqCredentialLog.md)
 - [XiqCwp](docs/models/XiqCwp.md)
 - [XiqD360ClientGridFilterRequest](docs/models/XiqD360ClientGridFilterRequest.md)
 - [XiqD360ClientGridMetadata](docs/models/XiqD360ClientGridMetadata.md)
 - [XiqD360DeviceStats](docs/models/XiqD360DeviceStats.md)
 - [XiqD360DeviceSummary](docs/models/XiqD360DeviceSummary.md)
 - [XiqD360Filter](docs/models/XiqD360Filter.md)
 - [XiqD360FilterType](docs/models/XiqD360FilterType.md)
 - [XiqD360NumberFilter](docs/models/XiqD360NumberFilter.md)
 - [XiqDashboardFilter](docs/models/XiqDashboardFilter.md)
 - [XiqDataPoint](docs/models/XiqDataPoint.md)
 - [XiqDateTimeType](docs/models/XiqDateTimeType.md)
 - [XiqDateTimeUnitType](docs/models/XiqDateTimeUnitType.md)
 - [XiqDefaultDevicePassword](docs/models/XiqDefaultDevicePassword.md)
 - [XiqDeleteBulkAlertSubscriptionEmailResponse](docs/models/XiqDeleteBulkAlertSubscriptionEmailResponse.md)
 - [XiqDeleteBulkAlertSubscriptionRequest](docs/models/XiqDeleteBulkAlertSubscriptionRequest.md)
 - [XiqDeleteBulkAlertSubscriptionServiceNowResponse](docs/models/XiqDeleteBulkAlertSubscriptionServiceNowResponse.md)
 - [XiqDeleteBulkAlertSubscriptionWebhookResponse](docs/models/XiqDeleteBulkAlertSubscriptionWebhookResponse.md)
 - [XiqDeleteKeyBasedPcgUsersRequest](docs/models/XiqDeleteKeyBasedPcgUsersRequest.md)
 - [XiqDeliverySettings](docs/models/XiqDeliverySettings.md)
 - [XiqDellDevice](docs/models/XiqDellDevice.md)
 - [XiqDellDevices](docs/models/XiqDellDevices.md)
 - [XiqDeployDeviceFilter](docs/models/XiqDeployDeviceFilter.md)
 - [XiqDeploymentByIdStatusResponse](docs/models/XiqDeploymentByIdStatusResponse.md)
 - [XiqDeploymentDetailsResponse](docs/models/XiqDeploymentDetailsResponse.md)
 - [XiqDeploymentOverview](docs/models/XiqDeploymentOverview.md)
 - [XiqDeploymentOverviewDetails](docs/models/XiqDeploymentOverviewDetails.md)
 - [XiqDeploymentPolicy](docs/models/XiqDeploymentPolicy.md)
 - [XiqDeploymentRequest](docs/models/XiqDeploymentRequest.md)
 - [XiqDeploymentResponse](docs/models/XiqDeploymentResponse.md)
 - [XiqDeploymentScheduleActionResponse](docs/models/XiqDeploymentScheduleActionResponse.md)
 - [XiqDeploymentStatus](docs/models/XiqDeploymentStatus.md)
 - [XiqDeploymentsPolicyResponse](docs/models/XiqDeploymentsPolicyResponse.md)
 - [XiqDestinationType](docs/models/XiqDestinationType.md)
 - [XiqDevice](docs/models/XiqDevice.md)
 - [XiqDeviceAdminState](docs/models/XiqDeviceAdminState.md)
 - [XiqDeviceAlarm](docs/models/XiqDeviceAlarm.md)
 - [XiqDeviceCategory](docs/models/XiqDeviceCategory.md)
 - [XiqDeviceClientMonitor](docs/models/XiqDeviceClientMonitor.md)
 - [XiqDeviceCpuMemoryUsage](docs/models/XiqDeviceCpuMemoryUsage.md)
 - [XiqDeviceCpuUsageIssueCount](docs/models/XiqDeviceCpuUsageIssueCount.md)
 - [XiqDeviceData](docs/models/XiqDeviceData.md)
 - [XiqDeviceDetails](docs/models/XiqDeviceDetails.md)
 - [XiqDeviceField](docs/models/XiqDeviceField.md)
 - [XiqDeviceFilter](docs/models/XiqDeviceFilter.md)
 - [XiqDeviceFirmwareMetadata](docs/models/XiqDeviceFirmwareMetadata.md)
 - [XiqDeviceFunction](docs/models/XiqDeviceFunction.md)
 - [XiqDeviceGeolocation](docs/models/XiqDeviceGeolocation.md)
 - [XiqDeviceHealthDashboard](docs/models/XiqDeviceHealthDashboard.md)
 - [XiqDeviceHealthGridResponse](docs/models/XiqDeviceHealthGridResponse.md)
 - [XiqDeviceIbeacon](docs/models/XiqDeviceIbeacon.md)
 - [XiqDeviceInstallationReport](docs/models/XiqDeviceInstallationReport.md)
 - [XiqDeviceInterfaceRadioMode](docs/models/XiqDeviceInterfaceRadioMode.md)
 - [XiqDeviceIotInterfaceSettingsEntry](docs/models/XiqDeviceIotInterfaceSettingsEntry.md)
 - [XiqDeviceIssues](docs/models/XiqDeviceIssues.md)
 - [XiqDeviceLevelSsid](docs/models/XiqDeviceLevelSsid.md)
 - [XiqDeviceLevelSsidStatus](docs/models/XiqDeviceLevelSsidStatus.md)
 - [XiqDeviceLldpCdpInfo](docs/models/XiqDeviceLldpCdpInfo.md)
 - [XiqDeviceLocation](docs/models/XiqDeviceLocation.md)
 - [XiqDeviceLocationAssignment](docs/models/XiqDeviceLocationAssignment.md)
 - [XiqDeviceMemoryUsageIssueCount](docs/models/XiqDeviceMemoryUsageIssueCount.md)
 - [XiqDeviceMetaData](docs/models/XiqDeviceMetaData.md)
 - [XiqDeviceMonitorRefreshResponse](docs/models/XiqDeviceMonitorRefreshResponse.md)
 - [XiqDeviceMonitorRefreshStatusResponse](docs/models/XiqDeviceMonitorRefreshStatusResponse.md)
 - [XiqDeviceNullField](docs/models/XiqDeviceNullField.md)
 - [XiqDevicePath](docs/models/XiqDevicePath.md)
 - [XiqDevicePoeUsageIssuesCount](docs/models/XiqDevicePoeUsageIssuesCount.md)
 - [XiqDeviceRadioOperatingMode](docs/models/XiqDeviceRadioOperatingMode.md)
 - [XiqDeviceRebootSummary](docs/models/XiqDeviceRebootSummary.md)
 - [XiqDeviceSortField](docs/models/XiqDeviceSortField.md)
 - [XiqDeviceStats](docs/models/XiqDeviceStats.md)
 - [XiqDeviceStatsEntity](docs/models/XiqDeviceStatsEntity.md)
 - [XiqDeviceSummary](docs/models/XiqDeviceSummary.md)
 - [XiqDeviceSystemInformation](docs/models/XiqDeviceSystemInformation.md)
 - [XiqDeviceType](docs/models/XiqDeviceType.md)
 - [XiqDeviceView](docs/models/XiqDeviceView.md)
 - [XiqDeviceWifiInterface](docs/models/XiqDeviceWifiInterface.md)
 - [XiqDeviceWirelessInterfaceEntry](docs/models/XiqDeviceWirelessInterfaceEntry.md)
 - [XiqDevices](docs/models/XiqDevices.md)
 - [XiqDfsChannelChangesEntity](docs/models/XiqDfsChannelChangesEntity.md)
 - [XiqDfsChannelStatsEntity](docs/models/XiqDfsChannelStatsEntity.md)
 - [XiqDfsRecurenceChannelStatsResponse](docs/models/XiqDfsRecurenceChannelStatsResponse.md)
 - [XiqDfsRecurenceCountStatsResponse](docs/models/XiqDfsRecurenceCountStatsResponse.md)
 - [XiqDigitalTwinDevice](docs/models/XiqDigitalTwinDevice.md)
 - [XiqDigitalTwinDevices](docs/models/XiqDigitalTwinDevices.md)
 - [XiqDigitalTwinFeatLicense](docs/models/XiqDigitalTwinFeatLicense.md)
 - [XiqDigitalTwinMake](docs/models/XiqDigitalTwinMake.md)
 - [XiqDigitalTwinModel](docs/models/XiqDigitalTwinModel.md)
 - [XiqDigitalTwinOnboardDevice](docs/models/XiqDigitalTwinOnboardDevice.md)
 - [XiqDigitalTwinProducts](docs/models/XiqDigitalTwinProducts.md)
 - [XiqDigitalTwinVimModule](docs/models/XiqDigitalTwinVimModule.md)
 - [XiqDuplexDataRateEntity](docs/models/XiqDuplexDataRateEntity.md)
 - [XiqEkahauFloorImportResult](docs/models/XiqEkahauFloorImportResult.md)
 - [XiqEkahauFloorImportStatus](docs/models/XiqEkahauFloorImportStatus.md)
 - [XiqEkahauFloorToFloorAssociation](docs/models/XiqEkahauFloorToFloorAssociation.md)
 - [XiqEkahauFloorToOutdoorSiteAssociation](docs/models/XiqEkahauFloorToOutdoorSiteAssociation.md)
 - [XiqEkahauImportDetails](docs/models/XiqEkahauImportDetails.md)
 - [XiqEkahauImportIssue](docs/models/XiqEkahauImportIssue.md)
 - [XiqEkahauImportIssues](docs/models/XiqEkahauImportIssues.md)
 - [XiqElevation](docs/models/XiqElevation.md)
 - [XiqEllipse](docs/models/XiqEllipse.md)
 - [XiqEmailLog](docs/models/XiqEmailLog.md)
 - [XiqEmailTemplate](docs/models/XiqEmailTemplate.md)
 - [XiqEmployeeGroup](docs/models/XiqEmployeeGroup.md)
 - [XiqEmployeeGroupType](docs/models/XiqEmployeeGroupType.md)
 - [XiqEmployeeGroupUpdate](docs/models/XiqEmployeeGroupUpdate.md)
 - [XiqEndUser](docs/models/XiqEndUser.md)
 - [XiqEntitlementType](docs/models/XiqEntitlementType.md)
 - [XiqError](docs/models/XiqError.md)
 - [XiqExcludedVlanActionType](docs/models/XiqExcludedVlanActionType.md)
 - [XiqExosDevice](docs/models/XiqExosDevice.md)
 - [XiqExosDevices](docs/models/XiqExosDevices.md)
 - [XiqExpirationActionType](docs/models/XiqExpirationActionType.md)
 - [XiqExpirationSettings](docs/models/XiqExpirationSettings.md)
 - [XiqExpirationType](docs/models/XiqExpirationType.md)
 - [XiqExternalAccount](docs/models/XiqExternalAccount.md)
 - [XiqExternalRadiusServer](docs/models/XiqExternalRadiusServer.md)
 - [XiqExternalUser](docs/models/XiqExternalUser.md)
 - [XiqExternalUserDirectory](docs/models/XiqExternalUserDirectory.md)
 - [XiqExternalUserDirectoryEntry](docs/models/XiqExternalUserDirectoryEntry.md)
 - [XiqExternalUserDirectoryType](docs/models/XiqExternalUserDirectoryType.md)
 - [XiqExtremeDevice](docs/models/XiqExtremeDevice.md)
 - [XiqExtremeDevices](docs/models/XiqExtremeDevices.md)
 - [XiqFailureOnboardDevice](docs/models/XiqFailureOnboardDevice.md)
 - [XiqFeedbackType](docs/models/XiqFeedbackType.md)
 - [XiqFilterType](docs/models/XiqFilterType.md)
 - [XiqFirmwareActivateOption](docs/models/XiqFirmwareActivateOption.md)
 - [XiqFirmwareMetadatasRequest](docs/models/XiqFirmwareMetadatasRequest.md)
 - [XiqFirmwareMetadatasResponse](docs/models/XiqFirmwareMetadatasResponse.md)
 - [XiqFirmwareUpgradePolicy](docs/models/XiqFirmwareUpgradePolicy.md)
 - [XiqFirmwareUpgradeVersion](docs/models/XiqFirmwareUpgradeVersion.md)
 - [XiqFlapCountEntity](docs/models/XiqFlapCountEntity.md)
 - [XiqFloor](docs/models/XiqFloor.md)
 - [XiqFolderPathInfo](docs/models/XiqFolderPathInfo.md)
 - [XiqForensicBucket](docs/models/XiqForensicBucket.md)
 - [XiqFtmSettings](docs/models/XiqFtmSettings.md)
 - [XiqFtmSettingsRequest](docs/models/XiqFtmSettingsRequest.md)
 - [XiqGenerateApiTokenRequest](docs/models/XiqGenerateApiTokenRequest.md)
 - [XiqGenerateApiTokenResponse](docs/models/XiqGenerateApiTokenResponse.md)
 - [XiqGetAfcSpectrumForApRequest](docs/models/XiqGetAfcSpectrumForApRequest.md)
 - [XiqGetAfcSpectrumForSiteApsRequest](docs/models/XiqGetAfcSpectrumForSiteApsRequest.md)
 - [XiqGetDeviceInfoByNos](docs/models/XiqGetDeviceInfoByNos.md)
 - [XiqGetDeviceInfobyNosRequest](docs/models/XiqGetDeviceInfobyNosRequest.md)
 - [XiqGetPortAssignmentDetailsResponse](docs/models/XiqGetPortAssignmentDetailsResponse.md)
 - [XiqGrantExternalUserRequest](docs/models/XiqGrantExternalUserRequest.md)
 - [XiqHardwareHealthClientListResponse](docs/models/XiqHardwareHealthClientListResponse.md)
 - [XiqHardwareHealthCpuMemStatsResponse](docs/models/XiqHardwareHealthCpuMemStatsResponse.md)
 - [XiqHardwareHealthDeviceStatsEntity](docs/models/XiqHardwareHealthDeviceStatsEntity.md)
 - [XiqHardwareHealthPacketCountsEntity](docs/models/XiqHardwareHealthPacketCountsEntity.md)
 - [XiqHardwareHealthRebootStatsEntity](docs/models/XiqHardwareHealthRebootStatsEntity.md)
 - [XiqHardwareHealthStatsResponse](docs/models/XiqHardwareHealthStatsResponse.md)
 - [XiqHhClientStatsEntity](docs/models/XiqHhClientStatsEntity.md)
 - [XiqHhCpuMemStatsEntity](docs/models/XiqHhCpuMemStatsEntity.md)
 - [XiqHiqContext](docs/models/XiqHiqContext.md)
 - [XiqHiqStatus](docs/models/XiqHiqStatus.md)
 - [XiqHostNameAddressProfile](docs/models/XiqHostNameAddressProfile.md)
 - [XiqHotspotAccessNetworkType](docs/models/XiqHotspotAccessNetworkType.md)
 - [XiqHotspotCellularNetwork](docs/models/XiqHotspotCellularNetwork.md)
 - [XiqHotspotConnectionCapability](docs/models/XiqHotspotConnectionCapability.md)
 - [XiqHotspotConnectionCapabilityProtocol](docs/models/XiqHotspotConnectionCapabilityProtocol.md)
 - [XiqHotspotConnectionCapabilityStatus](docs/models/XiqHotspotConnectionCapabilityStatus.md)
 - [XiqHotspotEapMethod](docs/models/XiqHotspotEapMethod.md)
 - [XiqHotspotIpv4AvailabilityType](docs/models/XiqHotspotIpv4AvailabilityType.md)
 - [XiqHotspotIpv6AvailabilityType](docs/models/XiqHotspotIpv6AvailabilityType.md)
 - [XiqHotspotLocalizedName](docs/models/XiqHotspotLocalizedName.md)
 - [XiqHotspotNaiEncodingType](docs/models/XiqHotspotNaiEncodingType.md)
 - [XiqHotspotNaiRealm](docs/models/XiqHotspotNaiRealm.md)
 - [XiqHotspotOnlineSignup](docs/models/XiqHotspotOnlineSignup.md)
 - [XiqHotspotOsuNetworkAuthType](docs/models/XiqHotspotOsuNetworkAuthType.md)
 - [XiqHotspotProfile](docs/models/XiqHotspotProfile.md)
 - [XiqHotspotProfileRequest](docs/models/XiqHotspotProfileRequest.md)
 - [XiqHotspotQosAhClassToDscpRange](docs/models/XiqHotspotQosAhClassToDscpRange.md)
 - [XiqHotspotQosDscpException](docs/models/XiqHotspotQosDscpException.md)
 - [XiqHotspotQosMap](docs/models/XiqHotspotQosMap.md)
 - [XiqHotspotRoamingConsortium](docs/models/XiqHotspotRoamingConsortium.md)
 - [XiqHotspotServiceProviderIconFile](docs/models/XiqHotspotServiceProviderIconFile.md)
 - [XiqHotspotServiceProviderOsuMethod](docs/models/XiqHotspotServiceProviderOsuMethod.md)
 - [XiqHotspotServiceProviderProfile](docs/models/XiqHotspotServiceProviderProfile.md)
 - [XiqHotspotServiceProviderProfileRequest](docs/models/XiqHotspotServiceProviderProfileRequest.md)
 - [XiqHotspotVenue](docs/models/XiqHotspotVenue.md)
 - [XiqHotspotVenueGroup](docs/models/XiqHotspotVenueGroup.md)
 - [XiqHotspotVenueType](docs/models/XiqHotspotVenueType.md)
 - [XiqHotspotWanLinkStatus](docs/models/XiqHotspotWanLinkStatus.md)
 - [XiqHotspotWanMetrics](docs/models/XiqHotspotWanMetrics.md)
 - [XiqHttpMethod](docs/models/XiqHttpMethod.md)
 - [XiqHttpServer](docs/models/XiqHttpServer.md)
 - [XiqInitKeyBasedPcgNetworkPolicyRequest](docs/models/XiqInitKeyBasedPcgNetworkPolicyRequest.md)
 - [XiqInitializeLocationRequest](docs/models/XiqInitializeLocationRequest.md)
 - [XiqInternalRadiusDevice](docs/models/XiqInternalRadiusDevice.md)
 - [XiqInternalRadiusServer](docs/models/XiqInternalRadiusServer.md)
 - [XiqInternalRadiusServerAuthenticationMethod](docs/models/XiqInternalRadiusServerAuthenticationMethod.md)
 - [XiqInternalRadiusServerAuthenticationMethodGroup](docs/models/XiqInternalRadiusServerAuthenticationMethodGroup.md)
 - [XiqIotApplicationId](docs/models/XiqIotApplicationId.md)
 - [XiqIotApplicationSupported](docs/models/XiqIotApplicationSupported.md)
 - [XiqIotProfile](docs/models/XiqIotProfile.md)
 - [XiqIotProfileRequest](docs/models/XiqIotProfileRequest.md)
 - [XiqIotProfileThreadGateway](docs/models/XiqIotProfileThreadGateway.md)
 - [XiqIotpMaBleBeacon](docs/models/XiqIotpMaBleBeacon.md)
 - [XiqIotpMaBleBeaconAppType](docs/models/XiqIotpMaBleBeaconAppType.md)
 - [XiqIotpMaBleBeaconApplication](docs/models/XiqIotpMaBleBeaconApplication.md)
 - [XiqIotpMaBleScan](docs/models/XiqIotpMaBleScan.md)
 - [XiqIotpMaBleScanAppType](docs/models/XiqIotpMaBleScanAppType.md)
 - [XiqIotpMaBleScanApplication](docs/models/XiqIotpMaBleScanApplication.md)
 - [XiqIotpMaBleScanDestination](docs/models/XiqIotpMaBleScanDestination.md)
 - [XiqIotpMaBleScanVendor](docs/models/XiqIotpMaBleScanVendor.md)
 - [XiqIotpMaBleScanVendorType](docs/models/XiqIotpMaBleScanVendorType.md)
 - [XiqIotpTgWhiteListEntry](docs/models/XiqIotpTgWhiteListEntry.md)
 - [XiqIpAddressProfile](docs/models/XiqIpAddressProfile.md)
 - [XiqIpFirewall](docs/models/XiqIpFirewall.md)
 - [XiqIpFirewallAction](docs/models/XiqIpFirewallAction.md)
 - [XiqIpFirewallPolicyRequest](docs/models/XiqIpFirewallPolicyRequest.md)
 - [XiqIpFirewallRule](docs/models/XiqIpFirewallRule.md)
 - [XiqIpFirewallRuleRequest](docs/models/XiqIpFirewallRuleRequest.md)
 - [XiqIpRangeAddressProfile](docs/models/XiqIpRangeAddressProfile.md)
 - [XiqIssueClientAssociation](docs/models/XiqIssueClientAssociation.md)
 - [XiqIssueClientAuth](docs/models/XiqIssueClientAuth.md)
 - [XiqIssueClientIpAddress](docs/models/XiqIssueClientIpAddress.md)
 - [XiqIssueClientRoaming](docs/models/XiqIssueClientRoaming.md)
 - [XiqKeyBasedPcg](docs/models/XiqKeyBasedPcg.md)
 - [XiqKeyBasedPcgUser](docs/models/XiqKeyBasedPcgUser.md)
 - [XiqKeyBasedPcgUserBaseInfo](docs/models/XiqKeyBasedPcgUserBaseInfo.md)
 - [XiqL3AddressProfile](docs/models/XiqL3AddressProfile.md)
 - [XiqL3AddressProfileResponse](docs/models/XiqL3AddressProfileResponse.md)
 - [XiqL3AddressType](docs/models/XiqL3AddressType.md)
 - [XiqLdapProtocolType](docs/models/XiqLdapProtocolType.md)
 - [XiqLdapServer](docs/models/XiqLdapServer.md)
 - [XiqLdapServerVerificationMode](docs/models/XiqLdapServerVerificationMode.md)
 - [XiqLicenseMode](docs/models/XiqLicenseMode.md)
 - [XiqLicenseStatus](docs/models/XiqLicenseStatus.md)
 - [XiqListAfcServers](docs/models/XiqListAfcServers.md)
 - [XiqListAlertPolicies](docs/models/XiqListAlertPolicies.md)
 - [XiqLocation](docs/models/XiqLocation.md)
 - [XiqLocationLegend](docs/models/XiqLocationLegend.md)
 - [XiqLocationTreeDevice](docs/models/XiqLocationTreeDevice.md)
 - [XiqLocationTreeMap](docs/models/XiqLocationTreeMap.md)
 - [XiqLocationType](docs/models/XiqLocationType.md)
 - [XiqLoggingType](docs/models/XiqLoggingType.md)
 - [XiqLoginRequest](docs/models/XiqLoginRequest.md)
 - [XiqLoginResponse](docs/models/XiqLoginResponse.md)
 - [XiqMacFirewall](docs/models/XiqMacFirewall.md)
 - [XiqMacFirewallAction](docs/models/XiqMacFirewallAction.md)
 - [XiqMacFirewallPolicyRequest](docs/models/XiqMacFirewallPolicyRequest.md)
 - [XiqMacFirewallRule](docs/models/XiqMacFirewallRule.md)
 - [XiqMacFirewallRuleRequest](docs/models/XiqMacFirewallRuleRequest.md)
 - [XiqMacObject](docs/models/XiqMacObject.md)
 - [XiqMacObjectType](docs/models/XiqMacObjectType.md)
 - [XiqMeasurementUnit](docs/models/XiqMeasurementUnit.md)
 - [XiqMissingVlanAffectedDeviceEntity](docs/models/XiqMissingVlanAffectedDeviceEntity.md)
 - [XiqMissingVlanAnomaliesCountResponse](docs/models/XiqMissingVlanAnomaliesCountResponse.md)
 - [XiqMissingVlanExcludedVlanDetails](docs/models/XiqMissingVlanExcludedVlanDetails.md)
 - [XiqMissingVlanExcludedVlanDetailsListRequest](docs/models/XiqMissingVlanExcludedVlanDetailsListRequest.md)
 - [XiqMissingVlanExcludedVlanList](docs/models/XiqMissingVlanExcludedVlanList.md)
 - [XiqMissingVlanInfo](docs/models/XiqMissingVlanInfo.md)
 - [XiqMissingVlanSiteAnomalyCountDetails](docs/models/XiqMissingVlanSiteAnomalyCountDetails.md)
 - [XiqNetworkAlgType](docs/models/XiqNetworkAlgType.md)
 - [XiqNetworkIpProtocol](docs/models/XiqNetworkIpProtocol.md)
 - [XiqNetworkPolicy](docs/models/XiqNetworkPolicy.md)
 - [XiqNetworkPolicyField](docs/models/XiqNetworkPolicyField.md)
 - [XiqNetworkPolicyInfo](docs/models/XiqNetworkPolicyInfo.md)
 - [XiqNetworkPolicyType](docs/models/XiqNetworkPolicyType.md)
 - [XiqNetworkPolicyView](docs/models/XiqNetworkPolicyView.md)
 - [XiqNetworkService](docs/models/XiqNetworkService.md)
 - [XiqNetworkServiceRequest](docs/models/XiqNetworkServiceRequest.md)
 - [XiqNumberFilter](docs/models/XiqNumberFilter.md)
 - [XiqOnboardDeviceRequest](docs/models/XiqOnboardDeviceRequest.md)
 - [XiqOnboardError](docs/models/XiqOnboardError.md)
 - [XiqOnboardKeyBasedPcgRequest](docs/models/XiqOnboardKeyBasedPcgRequest.md)
 - [XiqOnboardKeyBasedPcgResponse](docs/models/XiqOnboardKeyBasedPcgResponse.md)
 - [XiqOperationMetadata](docs/models/XiqOperationMetadata.md)
 - [XiqOperationObject](docs/models/XiqOperationObject.md)
 - [XiqOperationStatus](docs/models/XiqOperationStatus.md)
 - [XiqOrganization](docs/models/XiqOrganization.md)
 - [XiqOrganizationType](docs/models/XiqOrganizationType.md)
 - [XiqOsObject](docs/models/XiqOsObject.md)
 - [XiqPacketCapture](docs/models/XiqPacketCapture.md)
 - [XiqPacketCaptureField](docs/models/XiqPacketCaptureField.md)
 - [XiqPacketCaptureSortField](docs/models/XiqPacketCaptureSortField.md)
 - [XiqPacketCaptureStatus](docs/models/XiqPacketCaptureStatus.md)
 - [XiqPasswordCharacterType](docs/models/XiqPasswordCharacterType.md)
 - [XiqPasswordDbLocation](docs/models/XiqPasswordDbLocation.md)
 - [XiqPasswordSettings](docs/models/XiqPasswordSettings.md)
 - [XiqPasswordType](docs/models/XiqPasswordType.md)
 - [XiqPatchAlertServiceNowSubscriptionRequest](docs/models/XiqPatchAlertServiceNowSubscriptionRequest.md)
 - [XiqPcgAssignPortsRequest](docs/models/XiqPcgAssignPortsRequest.md)
 - [XiqPcgAssignPortsResponse](docs/models/XiqPcgAssignPortsResponse.md)
 - [XiqPcgPortAssignment](docs/models/XiqPcgPortAssignment.md)
 - [XiqPcgPortAssignmentEntry](docs/models/XiqPcgPortAssignmentEntry.md)
 - [XiqPcgPortAssignmentEntryDetail](docs/models/XiqPcgPortAssignmentEntryDetail.md)
 - [XiqPcgPortAssignmentEntryDeviceMeta](docs/models/XiqPcgPortAssignmentEntryDeviceMeta.md)
 - [XiqPcgPortAssignmentEntryEthUserMeta](docs/models/XiqPcgPortAssignmentEntryEthUserMeta.md)
 - [XiqPcgType](docs/models/XiqPcgType.md)
 - [XiqPermission](docs/models/XiqPermission.md)
 - [XiqPoeFlappingStatsResponse](docs/models/XiqPoeFlappingStatsResponse.md)
 - [XiqPoeTrendGraphsResponse](docs/models/XiqPoeTrendGraphsResponse.md)
 - [XiqPolicyRuleProtocolType](docs/models/XiqPolicyRuleProtocolType.md)
 - [XiqPortEfficiencySpeedDuplexStatsResponse](docs/models/XiqPortEfficiencySpeedDuplexStatsResponse.md)
 - [XiqPortEfficiencyStatsResponse](docs/models/XiqPortEfficiencyStatsResponse.md)
 - [XiqPostExpirationAction](docs/models/XiqPostExpirationAction.md)
 - [XiqPowerSourceEquipment](docs/models/XiqPowerSourceEquipment.md)
 - [XiqPskGenerationMethod](docs/models/XiqPskGenerationMethod.md)
 - [XiqQualityIndex](docs/models/XiqQualityIndex.md)
 - [XiqRadio](docs/models/XiqRadio.md)
 - [XiqRadioBands](docs/models/XiqRadioBands.md)
 - [XiqRadioEntity](docs/models/XiqRadioEntity.md)
 - [XiqRadioMode](docs/models/XiqRadioMode.md)
 - [XiqRadioOperatingModes](docs/models/XiqRadioOperatingModes.md)
 - [XiqRadioProfile](docs/models/XiqRadioProfile.md)
 - [XiqRadiusClient](docs/models/XiqRadiusClient.md)
 - [XiqRadiusClientObject](docs/models/XiqRadiusClientObject.md)
 - [XiqRadiusClientObjectEntry](docs/models/XiqRadiusClientObjectEntry.md)
 - [XiqRadiusClientObjectType](docs/models/XiqRadiusClientObjectType.md)
 - [XiqRadiusClientProfile](docs/models/XiqRadiusClientProfile.md)
 - [XiqRadiusClientProfileEntry](docs/models/XiqRadiusClientProfileEntry.md)
 - [XiqRadiusProxy](docs/models/XiqRadiusProxy.md)
 - [XiqRadiusProxyFormatType](docs/models/XiqRadiusProxyFormatType.md)
 - [XiqRadiusProxyRealm](docs/models/XiqRadiusProxyRealm.md)
 - [XiqRadiusServerType](docs/models/XiqRadiusServerType.md)
 - [XiqRecurrenceType](docs/models/XiqRecurrenceType.md)
 - [XiqRegenerateEndUserPasswordResponse](docs/models/XiqRegenerateEndUserPasswordResponse.md)
 - [XiqRfEnvironmentType](docs/models/XiqRfEnvironmentType.md)
 - [XiqRmChannelFilterType](docs/models/XiqRmChannelFilterType.md)
 - [XiqRmDevice](docs/models/XiqRmDevice.md)
 - [XiqRmDeviceCategory](docs/models/XiqRmDeviceCategory.md)
 - [XiqRmDeviceConnectionStatus](docs/models/XiqRmDeviceConnectionStatus.md)
 - [XiqRmDeviceListRequest](docs/models/XiqRmDeviceListRequest.md)
 - [XiqRmDeviceLocationDetails](docs/models/XiqRmDeviceLocationDetails.md)
 - [XiqRmDeviceMetdataResponse](docs/models/XiqRmDeviceMetdataResponse.md)
 - [XiqRmDeviceSortField](docs/models/XiqRmDeviceSortField.md)
 - [XiqRmSiteIdsRequest](docs/models/XiqRmSiteIdsRequest.md)
 - [XiqRmSourceFilterType](docs/models/XiqRmSourceFilterType.md)
 - [XiqRmStackMemberInfo](docs/models/XiqRmStackMemberInfo.md)
 - [XiqRpChannelSelection](docs/models/XiqRpChannelSelection.md)
 - [XiqRpMacOuiProfile](docs/models/XiqRpMacOuiProfile.md)
 - [XiqRpMiscellaneousSettings](docs/models/XiqRpMiscellaneousSettings.md)
 - [XiqRpNeighborhoodAnalysis](docs/models/XiqRpNeighborhoodAnalysis.md)
 - [XiqRpRadioUsageOptimization](docs/models/XiqRpRadioUsageOptimization.md)
 - [XiqRpSensorScanSettings](docs/models/XiqRpSensorScanSettings.md)
 - [XiqRpWmmQosSettings](docs/models/XiqRpWmmQosSettings.md)
 - [XiqRttsSessionResponse](docs/models/XiqRttsSessionResponse.md)
 - [XiqSchedule](docs/models/XiqSchedule.md)
 - [XiqScheduleDetails](docs/models/XiqScheduleDetails.md)
 - [XiqScheduleStatus](docs/models/XiqScheduleStatus.md)
 - [XiqScheduleType](docs/models/XiqScheduleType.md)
 - [XiqSendCliRequest](docs/models/XiqSendCliRequest.md)
 - [XiqSendCliResponse](docs/models/XiqSendCliResponse.md)
 - [XiqServerRole](docs/models/XiqServerRole.md)
 - [XiqSessionsDataEntity](docs/models/XiqSessionsDataEntity.md)
 - [XiqSetSsidModeDot1xRequest](docs/models/XiqSetSsidModeDot1xRequest.md)
 - [XiqSetSsidModePpskRequest](docs/models/XiqSetSsidModePpskRequest.md)
 - [XiqSetSsidModePskRequest](docs/models/XiqSetSsidModePskRequest.md)
 - [XiqSetSsidModeWepRequest](docs/models/XiqSetSsidModeWepRequest.md)
 - [XiqSite](docs/models/XiqSite.md)
 - [XiqSiteAfcSchedule](docs/models/XiqSiteAfcSchedule.md)
 - [XiqSiteDashboardResponse](docs/models/XiqSiteDashboardResponse.md)
 - [XiqSiteInfo](docs/models/XiqSiteInfo.md)
 - [XiqSitesByWiredEntity](docs/models/XiqSitesByWiredEntity.md)
 - [XiqSitesByWirelessEntity](docs/models/XiqSitesByWirelessEntity.md)
 - [XiqSmsLog](docs/models/XiqSmsLog.md)
 - [XiqSmsLogStatus](docs/models/XiqSmsLogStatus.md)
 - [XiqSmsTemplate](docs/models/XiqSmsTemplate.md)
 - [XiqSortField](docs/models/XiqSortField.md)
 - [XiqSortOrder](docs/models/XiqSortOrder.md)
 - [XiqSpectrumMismatchSummary](docs/models/XiqSpectrumMismatchSummary.md)
 - [XiqSpeedDuplexEntity](docs/models/XiqSpeedDuplexEntity.md)
 - [XiqSsid](docs/models/XiqSsid.md)
 - [XiqSsidAccessSecurity](docs/models/XiqSsidAccessSecurity.md)
 - [XiqSsidAccessSecurityType](docs/models/XiqSsidAccessSecurityType.md)
 - [XiqSsidAdvancedSettings](docs/models/XiqSsidAdvancedSettings.md)
 - [XiqSsidDot1xEncryptionMethod](docs/models/XiqSsidDot1xEncryptionMethod.md)
 - [XiqSsidDot1xKeyManagement](docs/models/XiqSsidDot1xKeyManagement.md)
 - [XiqSsidEncryptionMethod](docs/models/XiqSsidEncryptionMethod.md)
 - [XiqSsidKeyManagement](docs/models/XiqSsidKeyManagement.md)
 - [XiqSsidKeyType](docs/models/XiqSsidKeyType.md)
 - [XiqSsidMetadata](docs/models/XiqSsidMetadata.md)
 - [XiqSsidPpskKeyManagement](docs/models/XiqSsidPpskKeyManagement.md)
 - [XiqSsidPskEncryptionMethod](docs/models/XiqSsidPskEncryptionMethod.md)
 - [XiqSsidPskKeyManagement](docs/models/XiqSsidPskKeyManagement.md)
 - [XiqSsidSaeGroup](docs/models/XiqSsidSaeGroup.md)
 - [XiqSsidStatus](docs/models/XiqSsidStatus.md)
 - [XiqSsidWepAuthenticationMethod](docs/models/XiqSsidWepAuthenticationMethod.md)
 - [XiqSsidWepDefaultKey](docs/models/XiqSsidWepDefaultKey.md)
 - [XiqSsidWepEncryptionMethod](docs/models/XiqSsidWepEncryptionMethod.md)
 - [XiqSsidWepKeyManagement](docs/models/XiqSsidWepKeyManagement.md)
 - [XiqStorage](docs/models/XiqStorage.md)
 - [XiqSubnetAddressProfile](docs/models/XiqSubnetAddressProfile.md)
 - [XiqSubscriptionDataType](docs/models/XiqSubscriptionDataType.md)
 - [XiqSubscriptionMessageType](docs/models/XiqSubscriptionMessageType.md)
 - [XiqSubscriptionStatus](docs/models/XiqSubscriptionStatus.md)
 - [XiqSuccessOnboardDevice](docs/models/XiqSuccessOnboardDevice.md)
 - [XiqSurroundingAps](docs/models/XiqSurroundingAps.md)
 - [XiqThirdPartyApiConnection](docs/models/XiqThirdPartyApiConnection.md)
 - [XiqThirdPartyApplication](docs/models/XiqThirdPartyApplication.md)
 - [XiqThreadBackboneBorderRouterService](docs/models/XiqThreadBackboneBorderRouterService.md)
 - [XiqThreadBorderAgentService](docs/models/XiqThreadBorderAgentService.md)
 - [XiqThreadBorderRouterService](docs/models/XiqThreadBorderRouterService.md)
 - [XiqThreadCommissionerService](docs/models/XiqThreadCommissionerService.md)
 - [XiqThreadIpv6Setting](docs/models/XiqThreadIpv6Setting.md)
 - [XiqThreadLeaderService](docs/models/XiqThreadLeaderService.md)
 - [XiqThreadMleLinkMode](docs/models/XiqThreadMleLinkMode.md)
 - [XiqThreadNat64Service](docs/models/XiqThreadNat64Service.md)
 - [XiqThreadNetDataPrefix](docs/models/XiqThreadNetDataPrefix.md)
 - [XiqThreadNetDataRoute](docs/models/XiqThreadNetDataRoute.md)
 - [XiqThreadNetDataService](docs/models/XiqThreadNetDataService.md)
 - [XiqThreadNetworkConfig](docs/models/XiqThreadNetworkConfig.md)
 - [XiqThreadNetworkData](docs/models/XiqThreadNetworkData.md)
 - [XiqThreadNetworkInterface](docs/models/XiqThreadNetworkInterface.md)
 - [XiqThreadNetworkTopology](docs/models/XiqThreadNetworkTopology.md)
 - [XiqThreadNetworks](docs/models/XiqThreadNetworks.md)
 - [XiqThreadRouter](docs/models/XiqThreadRouter.md)
 - [XiqThreadRouterNeighbor](docs/models/XiqThreadRouterNeighbor.md)
 - [XiqThreadStartCommissionerRequest](docs/models/XiqThreadStartCommissionerRequest.md)
 - [XiqThreadStopCommissionerRequest](docs/models/XiqThreadStopCommissionerRequest.md)
 - [XiqThreadVersion](docs/models/XiqThreadVersion.md)
 - [XiqTopApplicationsUsage](docs/models/XiqTopApplicationsUsage.md)
 - [XiqTraffic](docs/models/XiqTraffic.md)
 - [XiqTrendGraphEntity](docs/models/XiqTrendGraphEntity.md)
 - [XiqTrendIndicator](docs/models/XiqTrendIndicator.md)
 - [XiqTunnelConcentrator](docs/models/XiqTunnelConcentrator.md)
 - [XiqTunnelConcentratorRequest](docs/models/XiqTunnelConcentratorRequest.md)
 - [XiqUcpEngine](docs/models/XiqUcpEngine.md)
 - [XiqUcpEngineInstance](docs/models/XiqUcpEngineInstance.md)
 - [XiqUcpEngines](docs/models/XiqUcpEngines.md)
 - [XiqUnaffectedDownlinkDevice](docs/models/XiqUnaffectedDownlinkDevice.md)
 - [XiqUpdateActionAnomalyDetails](docs/models/XiqUpdateActionAnomalyDetails.md)
 - [XiqUpdateAlertEmailSubscriptionRequest](docs/models/XiqUpdateAlertEmailSubscriptionRequest.md)
 - [XiqUpdateAlertRuleRequest](docs/models/XiqUpdateAlertRuleRequest.md)
 - [XiqUpdateAlertServiceNowSubscriptionRequest](docs/models/XiqUpdateAlertServiceNowSubscriptionRequest.md)
 - [XiqUpdateAlertWebhookSubscriptionRequest](docs/models/XiqUpdateAlertWebhookSubscriptionRequest.md)
 - [XiqUpdateAnomaliesAndDevicesRequest](docs/models/XiqUpdateAnomaliesAndDevicesRequest.md)
 - [XiqUpdateApiAccessTokenRequest](docs/models/XiqUpdateApiAccessTokenRequest.md)
 - [XiqUpdateBuildingRequest](docs/models/XiqUpdateBuildingRequest.md)
 - [XiqUpdateClassificationRequest](docs/models/XiqUpdateClassificationRequest.md)
 - [XiqUpdateClassificationRuleRequest](docs/models/XiqUpdateClassificationRuleRequest.md)
 - [XiqUpdateClientMonitorProfileRequest](docs/models/XiqUpdateClientMonitorProfileRequest.md)
 - [XiqUpdateCloudConfigGroupRequest](docs/models/XiqUpdateCloudConfigGroupRequest.md)
 - [XiqUpdateDeviceLevelSsidStatus](docs/models/XiqUpdateDeviceLevelSsidStatus.md)
 - [XiqUpdateEndUserRequest](docs/models/XiqUpdateEndUserRequest.md)
 - [XiqUpdateExternalRadiusServerRequest](docs/models/XiqUpdateExternalRadiusServerRequest.md)
 - [XiqUpdateExternalUserRequest](docs/models/XiqUpdateExternalUserRequest.md)
 - [XiqUpdateFirmwareUpgradeRequest](docs/models/XiqUpdateFirmwareUpgradeRequest.md)
 - [XiqUpdateFloorRequest](docs/models/XiqUpdateFloorRequest.md)
 - [XiqUpdateInternalRadiusServerRequest](docs/models/XiqUpdateInternalRadiusServerRequest.md)
 - [XiqUpdateKeyBasedPcgUsersRequest](docs/models/XiqUpdateKeyBasedPcgUsersRequest.md)
 - [XiqUpdateL3AddressProfileRequest](docs/models/XiqUpdateL3AddressProfileRequest.md)
 - [XiqUpdateLdapServerRequest](docs/models/XiqUpdateLdapServerRequest.md)
 - [XiqUpdateLocationRequest](docs/models/XiqUpdateLocationRequest.md)
 - [XiqUpdateMacObjectRequest](docs/models/XiqUpdateMacObjectRequest.md)
 - [XiqUpdateMissingVlanExcludedVlanResponse](docs/models/XiqUpdateMissingVlanExcludedVlanResponse.md)
 - [XiqUpdateNetworkPolicyRequest](docs/models/XiqUpdateNetworkPolicyRequest.md)
 - [XiqUpdateRadioProfileRequest](docs/models/XiqUpdateRadioProfileRequest.md)
 - [XiqUpdateRadiusClient](docs/models/XiqUpdateRadiusClient.md)
 - [XiqUpdateRadiusClientObjectRequest](docs/models/XiqUpdateRadiusClientObjectRequest.md)
 - [XiqUpdateRadiusProxyRealm](docs/models/XiqUpdateRadiusProxyRealm.md)
 - [XiqUpdateRadiusProxyRequest](docs/models/XiqUpdateRadiusProxyRequest.md)
 - [XiqUpdateRpChannelSelectionRequest](docs/models/XiqUpdateRpChannelSelectionRequest.md)
 - [XiqUpdateRpMacOuiProfileRequest](docs/models/XiqUpdateRpMacOuiProfileRequest.md)
 - [XiqUpdateRpMiscellaneousSettingsRequest](docs/models/XiqUpdateRpMiscellaneousSettingsRequest.md)
 - [XiqUpdateRpNeighborhoodAnalysisRequest](docs/models/XiqUpdateRpNeighborhoodAnalysisRequest.md)
 - [XiqUpdateRpRadioUsageOptimizationRequest](docs/models/XiqUpdateRpRadioUsageOptimizationRequest.md)
 - [XiqUpdateRpSensorScanSettingsRequest](docs/models/XiqUpdateRpSensorScanSettingsRequest.md)
 - [XiqUpdateRpWmmQosSettingsRequest](docs/models/XiqUpdateRpWmmQosSettingsRequest.md)
 - [XiqUpdateSiteRequest](docs/models/XiqUpdateSiteRequest.md)
 - [XiqUpdateSsidAdvancedSettingsRequest](docs/models/XiqUpdateSsidAdvancedSettingsRequest.md)
 - [XiqUpdateThirdPartyApiConnectionRequest](docs/models/XiqUpdateThirdPartyApiConnectionRequest.md)
 - [XiqUpdateUserGroupRequest](docs/models/XiqUpdateUserGroupRequest.md)
 - [XiqUpdateUserProfileRequest](docs/models/XiqUpdateUserProfileRequest.md)
 - [XiqUpdateUserRequest](docs/models/XiqUpdateUserRequest.md)
 - [XiqUpdateVhmSettingRequest](docs/models/XiqUpdateVhmSettingRequest.md)
 - [XiqUpdateVlanObjectClassifiedEntryRequest](docs/models/XiqUpdateVlanObjectClassifiedEntryRequest.md)
 - [XiqUpdateVlanProfileRequest](docs/models/XiqUpdateVlanProfileRequest.md)
 - [XiqUpdateWebhookSubscriptionRequest](docs/models/XiqUpdateWebhookSubscriptionRequest.md)
 - [XiqUsageAndCapacityDashboard](docs/models/XiqUsageAndCapacityDashboard.md)
 - [XiqUsageAndCapacityGridFilter](docs/models/XiqUsageAndCapacityGridFilter.md)
 - [XiqUsageCapacityGridResponse](docs/models/XiqUsageCapacityGridResponse.md)
 - [XiqUser](docs/models/XiqUser.md)
 - [XiqUserGroup](docs/models/XiqUserGroup.md)
 - [XiqUserGroupName](docs/models/XiqUserGroupName.md)
 - [XiqUserProfile](docs/models/XiqUserProfile.md)
 - [XiqUserProfileAssignment](docs/models/XiqUserProfileAssignment.md)
 - [XiqUserProfileAssignmentRadiusAttribute](docs/models/XiqUserProfileAssignmentRadiusAttribute.md)
 - [XiqUserProfileAssignmentRule](docs/models/XiqUserProfileAssignmentRule.md)
 - [XiqUserRole](docs/models/XiqUserRole.md)
 - [XiqValidDailySettings](docs/models/XiqValidDailySettings.md)
 - [XiqValidDuringDateSettings](docs/models/XiqValidDuringDateSettings.md)
 - [XiqValidForTimePeriodSettings](docs/models/XiqValidForTimePeriodSettings.md)
 - [XiqValidTimePeriodAfterFirstLogin](docs/models/XiqValidTimePeriodAfterFirstLogin.md)
 - [XiqValidTimePeriodAfterIdCreation](docs/models/XiqValidTimePeriodAfterIdCreation.md)
 - [XiqValidTimePeriodAfterType](docs/models/XiqValidTimePeriodAfterType.md)
 - [XiqVhmSetting](docs/models/XiqVhmSetting.md)
 - [XiqVhmSettingInfo](docs/models/XiqVhmSettingInfo.md)
 - [XiqVhmStatus](docs/models/XiqVhmStatus.md)
 - [XiqViq](docs/models/XiqViq.md)
 - [XiqViqExportImportStatusResponse](docs/models/XiqViqExportImportStatusResponse.md)
 - [XiqViqExportResponse](docs/models/XiqViqExportResponse.md)
 - [XiqViqImportResponse](docs/models/XiqViqImportResponse.md)
 - [XiqViqLicense](docs/models/XiqViqLicense.md)
 - [XiqViqOperationType](docs/models/XiqViqOperationType.md)
 - [XiqViqTaskProgress](docs/models/XiqViqTaskProgress.md)
 - [XiqVlanObjectClassifiedEntry](docs/models/XiqVlanObjectClassifiedEntry.md)
 - [XiqVlanProfile](docs/models/XiqVlanProfile.md)
 - [XiqVlanProfileFilter](docs/models/XiqVlanProfileFilter.md)
 - [XiqVossDevice](docs/models/XiqVossDevice.md)
 - [XiqVossDevices](docs/models/XiqVossDevices.md)
 - [XiqWebhookSubscription](docs/models/XiqWebhookSubscription.md)
 - [XiqWeekday](docs/models/XiqWeekday.md)
 - [XiqWgs84](docs/models/XiqWgs84.md)
 - [XiqWifiCapacityClientListResponse](docs/models/XiqWifiCapacityClientListResponse.md)
 - [XiqWifiCapacityStatsResponse](docs/models/XiqWifiCapacityStatsResponse.md)
 - [XiqWifiEfficiencyClientListResponse](docs/models/XiqWifiEfficiencyClientListResponse.md)
 - [XiqWifiEfficiencyStatsResponse](docs/models/XiqWifiEfficiencyStatsResponse.md)
 - [XiqWifiInterfaceType](docs/models/XiqWifiInterfaceType.md)
 - [XiqWildcardAddressProfile](docs/models/XiqWildcardAddressProfile.md)
 - [XiqWildcardHostNameAddressProfile](docs/models/XiqWildcardHostNameAddressProfile.md)
 - [XiqWingDevice](docs/models/XiqWingDevice.md)
 - [XiqWingDevices](docs/models/XiqWingDevices.md)
 - [XiqWiredEventEntity](docs/models/XiqWiredEventEntity.md)
 - [XiqWiredFilterType](docs/models/XiqWiredFilterType.md)
 - [XiqWiredHardwareByLocationResponse](docs/models/XiqWiredHardwareByLocationResponse.md)
 - [XiqWiredHardwareEntity](docs/models/XiqWiredHardwareEntity.md)
 - [XiqWiredHardwareResponse](docs/models/XiqWiredHardwareResponse.md)
 - [XiqWiredQualityIndexResponse](docs/models/XiqWiredQualityIndexResponse.md)
 - [XiqWiredViewType](docs/models/XiqWiredViewType.md)
 - [XiqWirelessAppsResponse](docs/models/XiqWirelessAppsResponse.md)
 - [XiqWirelessClient](docs/models/XiqWirelessClient.md)
 - [XiqWirelessClientHealthCriteriaParam](docs/models/XiqWirelessClientHealthCriteriaParam.md)
 - [XiqWirelessClientHealthGridFilterMetadata](docs/models/XiqWirelessClientHealthGridFilterMetadata.md)
 - [XiqWirelessConnectivityPerformanceResponse](docs/models/XiqWirelessConnectivityPerformanceResponse.md)
 - [XiqWirelessDashboardCriteriaParamResponse](docs/models/XiqWirelessDashboardCriteriaParamResponse.md)
 - [XiqWirelessDeviceHealthCriteriaParam](docs/models/XiqWirelessDeviceHealthCriteriaParam.md)
 - [XiqWirelessDeviceHealthGridFilter](docs/models/XiqWirelessDeviceHealthGridFilter.md)
 - [XiqWirelessDeviceHealthSortField](docs/models/XiqWirelessDeviceHealthSortField.md)
 - [XiqWirelessEventRetriesEntity](docs/models/XiqWirelessEventRetriesEntity.md)
 - [XiqWirelessFilterType](docs/models/XiqWirelessFilterType.md)
 - [XiqWirelessIfName](docs/models/XiqWirelessIfName.md)
 - [XiqWirelessIntPerDevice](docs/models/XiqWirelessIntPerDevice.md)
 - [XiqWirelessInterfaceGraph](docs/models/XiqWirelessInterfaceGraph.md)
 - [XiqWirelessInterfacesStats](docs/models/XiqWirelessInterfacesStats.md)
 - [XiqWirelessPerformanceEntity](docs/models/XiqWirelessPerformanceEntity.md)
 - [XiqWirelessPerformanceRetriesEntity](docs/models/XiqWirelessPerformanceRetriesEntity.md)
 - [XiqWirelessQualityIndexByLocationResponse](docs/models/XiqWirelessQualityIndexByLocationResponse.md)
 - [XiqWirelessQualityIndexResponse](docs/models/XiqWirelessQualityIndexResponse.md)
 - [XiqWirelessTimeToConnectEntity](docs/models/XiqWirelessTimeToConnectEntity.md)
 - [XiqWirelessTimeToConnectResponse](docs/models/XiqWirelessTimeToConnectResponse.md)
 - [XiqWirelessUsageCapacityCriteriaParam](docs/models/XiqWirelessUsageCapacityCriteriaParam.md)
 - [XiqWirelessUsageCapacityExcessiveUtilization](docs/models/XiqWirelessUsageCapacityExcessiveUtilization.md)
 - [XiqWirelessViewsListType](docs/models/XiqWirelessViewsListType.md)
 - [XiqWirelessViewsTypeResponse](docs/models/XiqWirelessViewsTypeResponse.md)
 - [XiqWirelessWifi](docs/models/XiqWirelessWifi.md)
 - [XiqWirelessWifi2](docs/models/XiqWirelessWifi2.md)
 - [XiqWirelessWlan](docs/models/XiqWirelessWlan.md)
 - [XiqZsubelement](docs/models/XiqZsubelement.md)
 - [XiqZsubelementAboveFloor](docs/models/XiqZsubelementAboveFloor.md)

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="Bearer"></a>
### Bearer

- **Type**: Bearer authentication (JWT)


## Author

support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com
support@extremenetworks.com

## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in extremecloudiq.apis and extremecloudiq.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from extremecloudiq.apis.default_api import DefaultApi`
- `from extremecloudiq.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import extremecloudiq
from extremecloudiq.apis import *
from extremecloudiq.models import *
```
